from collections import defaultdict
from skidl import Pin, Part, Alias, SchLib, SKIDL, TEMPLATE

from skidl.pin import pin_types

SKIDL_lib_version = '0.0.1'

Amplifier_Audio = SchLib(tool=SKIDL).add_parts(*[
        Part(**{ 'name':'IR4301', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IR4301'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Infineon_PQFN-22-15-4EP_6x5mm_P0.65mm'], 'footprint':'Package_DFN_QFN:Infineon_PQFN-22-15-4EP_6x5mm_P0.65mm', 'keywords':'integrated class d amplifier', 'description':'', 'datasheet':'https://www.infineon.com/dgdl/ir4301.pdf?fileId=5546d462533600a4015355d5fc691819', 'search_text':'/usr/share/kicad/symbols/Amplifier_Audio.kicad_sym\nIR4301\n\nintegrated class d amplifier', 'pins':[
            Pin(num='1',name='VAA',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='VN',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VS',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='VP',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VB',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='CSH',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='COM',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='IN+',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='IN-',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='COMP',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='CSD',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='COM',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IR4302', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IR4302'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Infineon_PQFN-44-31-5EP_7x7mm_P0.5mm'], 'footprint':'Package_DFN_QFN:Infineon_PQFN-44-31-5EP_7x7mm_P0.5mm', 'keywords':'integrated class d amplifier 2ch', 'description':'', 'datasheet':'https://www.infineon.com/dgdl/ir4302.pdf?fileId=5546d462533600a4015355d602a9181d', 'search_text':'/usr/share/kicad/symbols/Amplifier_Audio.kicad_sym\nIR4302\n\nintegrated class d amplifier 2ch', 'pins':[
            Pin(num='1',name='CLIP',func=pin_types.OPENCOLL,unit=1),
            Pin(num='10',name='COMP1',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='CSD',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='FAULT',func=pin_types.OPENCOLL,unit=1),
            Pin(num='13',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='14',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='COM',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='CSH1',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='VB1',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='VS1',func=pin_types.OUTPUT,unit=1),
            Pin(num='19',name='VP1',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='VS1',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='VN1',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='COM',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='30',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='31',name='COM',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VAA',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='IN+1',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='IN-1',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='COMP2',func=pin_types.OUTPUT,unit=2),
            Pin(num='22',name='VN2',func=pin_types.PWRIN,unit=2),
            Pin(num='23',name='VS2',func=pin_types.OUTPUT,unit=2),
            Pin(num='24',name='VP2',func=pin_types.PWRIN,unit=2),
            Pin(num='25',name='VS2',func=pin_types.PASSIVE,unit=2),
            Pin(num='26',name='VB2',func=pin_types.PWRIN,unit=2),
            Pin(num='27',name='CSH2',func=pin_types.PASSIVE,unit=2),
            Pin(num='3',name='IN-2',func=pin_types.INPUT,unit=2),
            Pin(num='4',name='IN+2',func=pin_types.INPUT,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['12', '21', '5', '6', '17', '9', '13', '11', '20', '19', '14', '28', '18', '31', '16', '8', '15', '1', '10', '7', '29', '30']},{'label': 'uB', 'num': 2, 'pin_nums': ['2', '3', '4', '25', '23', '22', '24', '27', '26']}] }),
        Part(**{ 'name':'IRS2052M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IRS2052M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Infineon_MLPQ-48-1EP_7x7mm_P0.5mm_EP5.55x5.55mm'], 'footprint':'Package_DFN_QFN:Infineon_MLPQ-48-1EP_7x7mm_P0.5mm_EP5.55x5.55mm', 'keywords':'Gate Driver Class D 2ch', 'description':'', 'datasheet':'https://www.infineon.com/dgdl/irs2052mpbf.pdf?fileId=5546d462533600a401535675d3b32788', 'search_text':'/usr/share/kicad/symbols/Amplifier_Audio.kicad_sym\nIRS2052M\n\nGate Driver Class D 2ch', 'pins':[
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='10',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='11',name='VS1',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='13',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='14',name='HO1',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='VB1',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='CSH1',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='LO1',func=pin_types.OUTPUT,unit=1),
            Pin(num='19',name='COM',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='25',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='27',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='28',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='29',name='OTP',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='COM',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='DT',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='OCSET',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='VREF',func=pin_types.PWROUT,unit=1),
            Pin(num='35',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='36',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='37',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='41',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='42',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='43',name='VAA',func=pin_types.PWRIN,unit=1),
            Pin(num='44',name='IN1',func=pin_types.INPUT,unit=1),
            Pin(num='45',name='COMP1',func=pin_types.OUTPUT,unit=1),
            Pin(num='46',name='CLIP1',func=pin_types.OPENCOLL,unit=1),
            Pin(num='47',name='CSD',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='49',name='COM',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='VCC2',func=pin_types.PWRIN,unit=2),
            Pin(num='2',name='OTW',func=pin_types.OPENCOLL,unit=2),
            Pin(num='20',name='LO2',func=pin_types.OUTPUT,unit=2),
            Pin(num='21',name='CSH2',func=pin_types.PASSIVE,unit=2),
            Pin(num='22',name='VB2',func=pin_types.PWRIN,unit=2),
            Pin(num='23',name='HO2',func=pin_types.OUTPUT,unit=2),
            Pin(num='26',name='VS2',func=pin_types.PASSIVE,unit=2),
            Pin(num='3',name='FAULT',func=pin_types.OPENCOLL,unit=2),
            Pin(num='38',name='CLIP2',func=pin_types.OPENCOLL,unit=2),
            Pin(num='39',name='COMP2',func=pin_types.OUTPUT,unit=2),
            Pin(num='4',name='CKO',func=pin_types.OUTPUT,unit=2),
            Pin(num='40',name='IN2',func=pin_types.INPUT,unit=2),
            Pin(num='5',name='X1B',func=pin_types.OUTPUT,unit=2),
            Pin(num='6',name='X1A',func=pin_types.INPUT,unit=2),
            Pin(num='7',name='X2B',func=pin_types.OUTPUT,unit=2),
            Pin(num='8',name='X2A',func=pin_types.INPUT,unit=2),
            Pin(num='9',name='XSL',func=pin_types.INPUT,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['19', '28', '41', '49', '36', '29', '37', '43', '12', '30', '1', '14', '17', '10', '42', '31', '11', '45', '13', '32', '15', '24', '44', '25', '35', '48', '33', '47', '16', '34', '27', '46']},{'label': 'uB', 'num': 2, 'pin_nums': ['18', '38', '4', '5', '7', '22', '20', '26', '23', '9', '2', '39', '40', '6', '3', '21', '8']}] }),
        Part(**{ 'name':'IRS2092', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IRS2092'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-16_W7.62mm'], 'footprint':'Package_DIP:DIP-16_W7.62mm', 'keywords':'Gate Driver Class D', 'description':'', 'datasheet':'http://www.infineon.com/dgdl/irs2092.pdf?fileId=5546d462533600a401535675f1be2790', 'search_text':'/usr/share/kicad/symbols/Amplifier_Audio.kicad_sym\nIRS2092\n\nGate Driver Class D', 'pins':[
            Pin(num='1',name='VAA',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='COM',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='LO',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VS',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='HO',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='VB',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='CSH',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='IN-',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='COMP',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='CSD',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VREF',func=pin_types.PWROUT,unit=1),
            Pin(num='8',name='OCSET',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='DT',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IRS2092S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IRS2092S'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-16_3.9x9.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-16_3.9x9.9mm_P1.27mm', 'keywords':'Gate Driver Class D', 'description':'', 'datasheet':'http://www.infineon.com/dgdl/irs2092.pdf?fileId=5546d462533600a401535675f1be2790', 'search_text':'/usr/share/kicad/symbols/Amplifier_Audio.kicad_sym\nIRS2092S\n\nGate Driver Class D', 'pins':[
            Pin(num='1',name='VAA',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='COM',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='LO',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VS',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='HO',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='VB',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='CSH',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='IN-',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='COMP',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='CSD',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VREF',func=pin_types.PWROUT,unit=1),
            Pin(num='8',name='OCSET',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='DT',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IRS2093M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IRS2093M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Infineon_MLPQ-48-1EP_7x7mm_P0.5mm_EP5.55x5.55mm'], 'footprint':'Package_DFN_QFN:Infineon_MLPQ-48-1EP_7x7mm_P0.5mm_EP5.55x5.55mm', 'keywords':'Gate Driver Class D 4ch', 'description':'', 'datasheet':'https://www.infineon.com/dgdl/irs2093mpbf.pdf?fileId=5546d462533600a401535675fb892793', 'search_text':'/usr/share/kicad/symbols/Amplifier_Audio.kicad_sym\nIRS2093M\n\nGate Driver Class D 4ch', 'pins':[
            Pin(num='1',name='DS',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='VS1',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='HO1',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='VB1',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='CSH1',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='LO1',func=pin_types.OUTPUT,unit=1),
            Pin(num='18',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='19',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='20',name='COM',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='31',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='32',name='COM',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='34',name='DT',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='OCSET',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='VREF',func=pin_types.PWROUT,unit=1),
            Pin(num='4',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='41',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='42',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='43',name='VAA',func=pin_types.PWRIN,unit=1),
            Pin(num='46',name='IN1',func=pin_types.INPUT,unit=1),
            Pin(num='47',name='COMP1',func=pin_types.OUTPUT,unit=1),
            Pin(num='48',name='CSD',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='COM',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='10',name='VS2',func=pin_types.PASSIVE,unit=2),
            Pin(num='16',name='LO2',func=pin_types.OUTPUT,unit=2),
            Pin(num='17',name='VCC2',func=pin_types.PWRIN,unit=2),
            Pin(num='44',name='IN2',func=pin_types.INPUT,unit=2),
            Pin(num='45',name='COMP2',func=pin_types.OUTPUT,unit=2),
            Pin(num='7',name='CSH2',func=pin_types.PASSIVE,unit=2),
            Pin(num='8',name='VB2',func=pin_types.PWRIN,unit=2),
            Pin(num='9',name='HO2',func=pin_types.OUTPUT,unit=2),
            Pin(num='22',name='LO3',func=pin_types.OUTPUT,unit=3),
            Pin(num='23',name='CSH3',func=pin_types.PASSIVE,unit=3),
            Pin(num='24',name='VB3',func=pin_types.PWRIN,unit=3),
            Pin(num='25',name='HO3',func=pin_types.OUTPUT,unit=3),
            Pin(num='26',name='VS3',func=pin_types.PASSIVE,unit=3),
            Pin(num='37',name='COMP3',func=pin_types.OUTPUT,unit=3),
            Pin(num='38',name='IN3',func=pin_types.INPUT,unit=3),
            Pin(num='21',name='LO4',func=pin_types.OUTPUT,unit=4),
            Pin(num='27',name='VS4',func=pin_types.PASSIVE,unit=4),
            Pin(num='28',name='HO4',func=pin_types.OUTPUT,unit=4),
            Pin(num='29',name='VB4',func=pin_types.PWRIN,unit=4),
            Pin(num='30',name='CSH4',func=pin_types.PASSIVE,unit=4),
            Pin(num='39',name='COMP4',func=pin_types.OUTPUT,unit=4),
            Pin(num='40',name='IN4',func=pin_types.INPUT,unit=4)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['31', '42', '2', '13', '43', '15', '32', '33', '46', '12', '34', '47', '18', '49', '20', '1', '14', '35', '48', '4', '36', '5', '19', '6', '11', '41', '3']},{'label': 'uB', 'num': 2, 'pin_nums': ['16', '44', '7', '9', '17', '10', '45', '8']},{'label': 'uC', 'num': 3, 'pin_nums': ['25', '37', '23', '22', '24', '26', '38']},{'label': 'uD', 'num': 4, 'pin_nums': ['27', '29', '39', '21', '28', '30', '40']}] }),
        Part(**{ 'name':'IRS20957S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IRS20957S'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-16_3.9x9.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-16_3.9x9.9mm_P1.27mm', 'keywords':'Gate Driver Class D', 'description':'', 'datasheet':'http://www.infineon.com/dgdl/irs20957spbf.pdf?fileId=5546d462533600a401535676143e2799', 'search_text':'/usr/share/kicad/symbols/Amplifier_Audio.kicad_sym\nIRS20957S\n\nGate Driver Class D', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='LO',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='13',name='VS',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='HO',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='VB',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='CSH',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='CSD',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='IN',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='VREF',func=pin_types.PWROUT,unit=1),
            Pin(num='7',name='OCSET',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='DT',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='COM',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IRS20965S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IRS20965S'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-16_3.9x9.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-16_3.9x9.9mm_P1.27mm', 'keywords':'Gate Driver Class D', 'description':'', 'datasheet':'https://www.infineon.com/dgdl/irs20965spbf.pdf?fileId=5546d462533600a4015356761d8b279b', 'search_text':'/usr/share/kicad/symbols/Amplifier_Audio.kicad_sym\nIRS20965S\n\nGate Driver Class D', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='LO',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='STP',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='VS',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='HO',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='VB',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='CSH',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='CSD',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='OC',func=pin_types.OPENCOLL,unit=1),
            Pin(num='4',name='HIN',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='LIN',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VREF',func=pin_types.PWROUT,unit=1),
            Pin(num='8',name='OCSET',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='COM',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IRS2452AM', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IRS2452AM'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Infineon_MLPQ-40-32-1EP_7x7mm_P0.5mm'], 'footprint':'Package_DFN_QFN:Infineon_MLPQ-40-32-1EP_7x7mm_P0.5mm', 'keywords':'Gate Driver Class D 2ch', 'description':'', 'datasheet':'https://www.infineon.com/dgdl/Infineon-IRS2452AM-DS-v01_00-EN.pdf?fileId=5546d462584d1d4a01584ee4f1f00713', 'search_text':'/usr/share/kicad/symbols/Amplifier_Audio.kicad_sym\nIRS2452AM\n\nGate Driver Class D 2ch', 'pins':[
            Pin(num='10',name='COMP1',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='CSD',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='BTL',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='CSH1',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='VB1',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='HO1',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='VS1',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='CSL1',func=pin_types.PASSIVE,unit=1),
            Pin(num='18',name='LO1',func=pin_types.OUTPUT,unit=1),
            Pin(num='19',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='20',name='COM',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='22',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='OTP',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='DT',func=pin_types.PASSIVE,unit=1),
            Pin(num='31',name='A/B',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='COM',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='VAA',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='7',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='IN+1',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='IN-1',func=pin_types.INPUT,unit=1),
            Pin(num='1',name='COMP2',func=pin_types.OUTPUT,unit=2),
            Pin(num='2',name='IN-2',func=pin_types.INPUT,unit=2),
            Pin(num='25',name='LO2',func=pin_types.OUTPUT,unit=2),
            Pin(num='26',name='CSL2',func=pin_types.PASSIVE,unit=2),
            Pin(num='27',name='VS2',func=pin_types.PASSIVE,unit=2),
            Pin(num='28',name='HO2',func=pin_types.OUTPUT,unit=2),
            Pin(num='29',name='VB2',func=pin_types.PWRIN,unit=2),
            Pin(num='3',name='IN+2',func=pin_types.INPUT,unit=2),
            Pin(num='30',name='CSH2',func=pin_types.PASSIVE,unit=2),
            Pin(num='32',name='CLK',func=pin_types.INPUT,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['6', '4', '21', '5', '12', '23', '31', '13', '24', '22', '33', '7', '15', '10', '11', '16', '14', '17', '9', '19', '18', '8', '20']},{'label': 'uB', 'num': 2, 'pin_nums': ['28', '1', '25', '27', '30', '29', '2', '26', '32', '3']}] }),
        Part(**{ 'name':'IS31AP4991-GRLS2', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IS31AP4991-GRLS2'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOP-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOP-8_3.9x4.9mm_P1.27mm', 'keywords':'ultra low consumption distortion', 'description':'', 'datasheet':'http://www.issi.com/WW/pdf/31AP4991.pdf', 'search_text':'/usr/share/kicad/symbols/Amplifier_Audio.kicad_sym\nIS31AP4991-GRLS2\n\nultra low consumption distortion', 'pins':[
            Pin(num='1',name='+',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='-',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='BYP',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='~{SDB}',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='V+',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IS31AP4991-SLS2', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IS31AP4991-SLS2'}), 'ref_prefix':'U', 'fplist':['Package_SO:MSOP-8_3x3mm_P0.65mm'], 'footprint':'Package_SO:MSOP-8_3x3mm_P0.65mm', 'keywords':'ultra low consumption distortion', 'description':'', 'datasheet':'http://www.issi.com/WW/pdf/31AP4991.pdf', 'search_text':'/usr/share/kicad/symbols/Amplifier_Audio.kicad_sym\nIS31AP4991-SLS2\n\nultra low consumption distortion', 'pins':[
            Pin(num='1',name='~{SDB}',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='BYP',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='+',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='-',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='V+',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='~',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LM1875', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LM1875'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_THT:TO-220-5_P3.4x3.7mm_StaggerOdd_Lead3.8mm_Vertical'], 'footprint':'Package_TO_SOT_THT:TO-220-5_P3.4x3.7mm_StaggerOdd_Lead3.8mm_Vertical', 'keywords':'audio amplifier', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/lm1875.pdf', 'search_text':'/usr/share/kicad/symbols/Amplifier_Audio.kicad_sym\nLM1875\n\naudio amplifier', 'pins':[
            Pin(num='1',name='+',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='-',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='V-',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='V+',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LM1876', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LM1876'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_THT:TO-220-15_P2.54x2.54mm_StaggerOdd_Lead4.58mm_Vertical'], 'footprint':'Package_TO_SOT_THT:TO-220-15_P2.54x2.54mm_StaggerOdd_Lead4.58mm_Vertical', 'keywords':'audio amplifier 2ch', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/lm1876.pdf', 'search_text':'/usr/share/kicad/symbols/Amplifier_Audio.kicad_sym\nLM1876\n\naudio amplifier 2ch', 'pins':[
            Pin(num='2',name='V+',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='V-',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='MUTE',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='-',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='+',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='STBY',func=pin_types.INPUT,unit=1),
            Pin(num='1',name='~',func=pin_types.OUTPUT,unit=2),
            Pin(num='10',name='GND',func=pin_types.PWRIN,unit=2),
            Pin(num='11',name='MUTE',func=pin_types.INPUT,unit=2),
            Pin(num='12',name='-',func=pin_types.INPUT,unit=2),
            Pin(num='13',name='+',func=pin_types.INPUT,unit=2),
            Pin(num='14',name='STBY',func=pin_types.INPUT,unit=2),
            Pin(num='15',name='V+',func=pin_types.PWRIN,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['3', '6', '9', '2', '7', '5', '8', '4']},{'label': 'uB', 'num': 2, 'pin_nums': ['1', '10', '11', '13', '12', '14', '15']}] }),
        Part(**{ 'name':'LM1877', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LM1877'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'audio amplifier 2ch', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/lm1877.pdf', 'search_text':'/usr/share/kicad/symbols/Amplifier_Audio.kicad_sym\nLM1877\n\naudio amplifier 2ch', 'pins':[
            Pin(num='1',name='BIAS',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='+',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='-',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='~',func=pin_types.OUTPUT,unit=2),
            Pin(num='8',name='-',func=pin_types.INPUT,unit=2),
            Pin(num='9',name='+',func=pin_types.INPUT,unit=2),
            Pin(num='10',name='GND',func=pin_types.PASSIVE,unit=3),
            Pin(num='11',name='GND',func=pin_types.PASSIVE,unit=3),
            Pin(num='12',name='GND',func=pin_types.PASSIVE,unit=3),
            Pin(num='14',name='V+',func=pin_types.PWRIN,unit=3),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=3),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=3),
            Pin(num='5',name='GND',func=pin_types.PASSIVE,unit=3)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['7', '1', '6', '2']},{'label': 'uB', 'num': 2, 'pin_nums': ['9', '8', '13']},{'label': 'uC', 'num': 3, 'pin_nums': ['4', '12', '3', '10', '11', '14', '5']}] }),
        Part(**{ 'name':'LM2876', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LM2876'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_THT:TO-220-11_P3.4x5.08mm_StaggerOdd_Lead4.85mm_Vertical'], 'footprint':'Package_TO_SOT_THT:TO-220-11_P3.4x5.08mm_StaggerOdd_Lead4.85mm_Vertical', 'keywords':'audio amplifier 2ch', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/lm2876.pdf', 'search_text':'/usr/share/kicad/symbols/Amplifier_Audio.kicad_sym\nLM2876\n\naudio amplifier 2ch', 'pins':[
            Pin(num='1',name='V+',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='+',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='3',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='V-',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='7',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='MUTE',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='-',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LM380N', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LM380N'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-14_W7.62mm'], 'footprint':'Package_DIP:DIP-14_W7.62mm', 'keywords':'audio amplifier', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/lm380.pdf', 'search_text':'/usr/share/kicad/symbols/Amplifier_Audio.kicad_sym\nLM380N\n\naudio amplifier', 'pins':[
            Pin(num='1',name='BYPASS',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='14',name='VS',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='+',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='-',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LM380N-8', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LM380N-8'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-8_W7.62mm'], 'footprint':'Package_DIP:DIP-8_W7.62mm', 'keywords':'audio amplifier', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/lm380.pdf', 'search_text':'/usr/share/kicad/symbols/Amplifier_Audio.kicad_sym\nLM380N-8\n\naudio amplifier', 'pins':[
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='+',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='-',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='VS',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='BYPASS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LM384', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LM384'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-14_W7.62mm'], 'footprint':'Package_DIP:DIP-14_W7.62mm', 'keywords':'audio amplifier', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/lm384.pdf', 'search_text':'/usr/share/kicad/symbols/Amplifier_Audio.kicad_sym\nLM384\n\naudio amplifier', 'pins':[
            Pin(num='1',name='BYPASS',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='11',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='14',name='VS',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='+',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='-',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LM386', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LM386'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'single Power opamp', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/lm386.pdf', 'search_text':'/usr/share/kicad/symbols/Amplifier_Audio.kicad_sym\nLM386\n\nsingle Power opamp', 'pins':[
            Pin(num='1',name='GAIN',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='-',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='+',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='V+',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='BYPASS',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='GAIN',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LM3886', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LM3886'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_THT:TO-220-11_P3.4x5.08mm_StaggerOdd_Lead4.85mm_Vertical'], 'footprint':'Package_TO_SOT_THT:TO-220-11_P3.4x5.08mm_StaggerOdd_Lead4.85mm_Vertical', 'keywords':'audio amplifier', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/lm3886.pdf', 'search_text':'/usr/share/kicad/symbols/Amplifier_Audio.kicad_sym\nLM3886\n\naudio amplifier', 'pins':[
            Pin(num='1',name='V+',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='+',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='3',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='V-',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='V+',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='7',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='MUTE',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='-',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LM4752TS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LM4752TS'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:TO-263-7_TabPin4'], 'footprint':'Package_TO_SOT_SMD:TO-263-7_TabPin4', 'keywords':'audio amplifier 2ch', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/lm4752.pdf', 'search_text':'/usr/share/kicad/symbols/Amplifier_Audio.kicad_sym\nLM4752TS\n\naudio amplifier 2ch', 'pins':[
            Pin(num='5',name='BIAS',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='+',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='1',name='~',func=pin_types.OUTPUT,unit=2),
            Pin(num='2',name='+',func=pin_types.INPUT,unit=2),
            Pin(num='3',name='V+',func=pin_types.PWRIN,unit=3),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=3)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['5', '6', '7']},{'label': 'uB', 'num': 2, 'pin_nums': ['1', '2']},{'label': 'uC', 'num': 3, 'pin_nums': ['3', '4']}] }),
        Part(**{ 'name':'LM4755TS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LM4755TS'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:TO-263-9_TabPin5'], 'footprint':'Package_TO_SOT_SMD:TO-263-9_TabPin5', 'keywords':'audio amplifier 2ch', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/lm4755.pdf', 'search_text':'/usr/share/kicad/symbols/Amplifier_Audio.kicad_sym\nLM4755TS\n\naudio amplifier 2ch', 'pins':[
            Pin(num='2',name='MUTE',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='BIAS',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='+',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='1',name='~',func=pin_types.OUTPUT,unit=2),
            Pin(num='3',name='+',func=pin_types.INPUT,unit=2),
            Pin(num='4',name='V+',func=pin_types.PWRIN,unit=3),
            Pin(num='5',name='GND',func=pin_types.PWRIN,unit=3)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['2', '9', '8', '6', '7']},{'label': 'uB', 'num': 2, 'pin_nums': ['1', '3']},{'label': 'uC', 'num': 3, 'pin_nums': ['5', '4']}] }),
        Part(**{ 'name':'LM4766', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LM4766'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_THT:TO-220-15_P2.54x2.54mm_StaggerOdd_Lead4.58mm_Vertical'], 'footprint':'Package_TO_SOT_THT:TO-220-15_P2.54x2.54mm_StaggerOdd_Lead4.58mm_Vertical', 'keywords':'audio amplifier 2ch', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/lm4766.pdf', 'search_text':'/usr/share/kicad/symbols/Amplifier_Audio.kicad_sym\nLM4766\n\naudio amplifier 2ch', 'pins':[
            Pin(num='2',name='V+',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='V-',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='MUTE',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='-',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='+',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='1',name='~',func=pin_types.OUTPUT,unit=2),
            Pin(num='10',name='GND',func=pin_types.PWRIN,unit=2),
            Pin(num='11',name='MUTE',func=pin_types.INPUT,unit=2),
            Pin(num='12',name='-',func=pin_types.INPUT,unit=2),
            Pin(num='13',name='+',func=pin_types.INPUT,unit=2),
            Pin(num='14',name='NC',func=pin_types.NOCONNECT,unit=2),
            Pin(num='15',name='V+',func=pin_types.PWRIN,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['7', '3', '2', '4', '5', '8', '9', '6']},{'label': 'uB', 'num': 2, 'pin_nums': ['15', '1', '10', '12', '14', '13', '11']}] }),
        Part(**{ 'name':'LM4810', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LM4810'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-8_3x3mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-8_3x3mm_P0.65mm', 'keywords':'audio amplifier headphone', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/lm4810.pdf', 'search_text':'/usr/share/kicad/symbols/Amplifier_Audio.kicad_sym\nLM4810\n\naudio amplifier headphone', 'pins':[
            Pin(num='1',name='VOUT1',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='VIN1',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='BYPASS',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='SHDN',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='VIN2',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='VOUT2',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='VDD',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LM4811', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LM4811'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-10_3x3mm_P0.5mm'], 'footprint':'Package_SO:TSSOP-10_3x3mm_P0.5mm', 'keywords':'audio amplifier headphone 2ch', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/lm4811.pdf', 'search_text':'/usr/share/kicad/symbols/Amplifier_Audio.kicad_sym\nLM4811\n\naudio amplifier headphone 2ch', 'pins':[
            Pin(num='1',name='VOUT1',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='VIN1',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='BYPASS',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='CLOCK',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='UP/DN',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='SHDN',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VIN2',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='VOUT2',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LM4950TA', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LM4950TA'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_THT:TO-220-5_P3.4x3.7mm_StaggerOdd_Lead3.8mm_Vertical'], 'footprint':'Package_TO_SOT_THT:TO-220-5_P3.4x3.7mm_StaggerOdd_Lead3.8mm_Vertical', 'keywords':'audio amplifier', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/lm4950.pdf', 'search_text':'/usr/share/kicad/symbols/Amplifier_Audio.kicad_sym\nLM4950TA\n\naudio amplifier', 'pins':[
            Pin(num='1',name='VINA',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~{SHDN}',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='BYP',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='~',func=pin_types.OUTPUT,unit=2),
            Pin(num='9',name='VINB',func=pin_types.INPUT,unit=2),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=3),
            Pin(num='5',name='GND',func=pin_types.PASSIVE,unit=3),
            Pin(num='6',name='VDD',func=pin_types.PWRIN,unit=3)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['2', '8', '1', '3']},{'label': 'uB', 'num': 2, 'pin_nums': ['9', '7']},{'label': 'uC', 'num': 3, 'pin_nums': ['4', '6', '5']}] }),
        Part(**{ 'name':'LM4950TS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LM4950TS'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:TO-263-9_TabPin5'], 'footprint':'Package_TO_SOT_SMD:TO-263-9_TabPin5', 'keywords':'audio amplifier', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/lm4950.pdf', 'search_text':'/usr/share/kicad/symbols/Amplifier_Audio.kicad_sym\nLM4950TS\n\naudio amplifier', 'pins':[
            Pin(num='1',name='VINA',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~{SHDN}',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='BYP',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='~',func=pin_types.OUTPUT,unit=2),
            Pin(num='9',name='VINB',func=pin_types.INPUT,unit=2),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=3),
            Pin(num='5',name='GND',func=pin_types.PASSIVE,unit=3),
            Pin(num='6',name='VDD',func=pin_types.PWRIN,unit=3)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['2', '8', '1', '3']},{'label': 'uB', 'num': 2, 'pin_nums': ['7', '9']},{'label': 'uC', 'num': 3, 'pin_nums': ['6', '5', '4']}] }),
        Part(**{ 'name':'LM4990ITL', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LM4990ITL'}), 'ref_prefix':'U', 'fplist':['Package_BGA:Texas_DSBGA-9_1.4715x1.4715mm_Layout3x3_P0.5mm'], 'footprint':'Package_BGA:Texas_DSBGA-9_1.4715x1.4715mm_Layout3x3_P0.5mm', 'keywords':'audio amplifier class d', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/lm4990.pdf', 'search_text':'/usr/share/kicad/symbols/Amplifier_Audio.kicad_sym\nLM4990ITL\n\naudio amplifier class d', 'pins':[
            Pin(num='A1',name='-',func=pin_types.INPUT,unit=1),
            Pin(num='A2',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='A3',name='+',func=pin_types.INPUT,unit=1),
            Pin(num='B1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='B2',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='B3',name='V+',func=pin_types.PWRIN,unit=1),
            Pin(num='C1',name='BYP',func=pin_types.INPUT,unit=1),
            Pin(num='C2',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='C3',name='~{SHDN}',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LM4990LD', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LM4990LD'}), 'ref_prefix':'U', 'fplist':['Package_SON:WSON-10-1EP_4x3mm_P0.5mm_EP2.2x2mm'], 'footprint':'Package_SON:WSON-10-1EP_4x3mm_P0.5mm_EP2.2x2mm', 'keywords':'audio amplifier class d', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/lm4990.pdf', 'search_text':'/usr/share/kicad/symbols/Amplifier_Audio.kicad_sym\nLM4990LD\n\naudio amplifier class d', 'pins':[
            Pin(num='1',name='SHDN',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='~',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='BYP',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='SD',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='+',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='-',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='V+',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='GND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LM4990MH', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LM4990MH'}), 'ref_prefix':'U', 'fplist':['Package_SO:MSOP-10-1EP_3x3mm_P0.5mm_EP1.68x1.88mm'], 'footprint':'Package_SO:MSOP-10-1EP_3x3mm_P0.5mm_EP1.68x1.88mm', 'keywords':'audio amplifier class d', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/lm4990.pdf', 'search_text':'/usr/share/kicad/symbols/Amplifier_Audio.kicad_sym\nLM4990MH\n\naudio amplifier class d', 'pins':[
            Pin(num='1',name='~{SHDN}',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='~',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='BYP',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='SD',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='+',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='-',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='V+',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='GND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LM4990MM', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LM4990MM'}), 'ref_prefix':'U', 'fplist':['Package_SO:TSSOP-8_3x3mm_P0.65mm'], 'footprint':'Package_SO:TSSOP-8_3x3mm_P0.65mm', 'keywords':'audio amplifier class d', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/lm4990.pdf', 'search_text':'/usr/share/kicad/symbols/Amplifier_Audio.kicad_sym\nLM4990MM\n\naudio amplifier class d', 'pins':[
            Pin(num='1',name='~{SHDN}',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='BYP',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='+',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='-',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='V+',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='~',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LME49600', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LME49600'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:TO-263-5_TabPin3'], 'footprint':'Package_TO_SOT_SMD:TO-263-5_TabPin3', 'keywords':'audio buffer amplifier', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/lme49600.pdf', 'search_text':'/usr/share/kicad/symbols/Amplifier_Audio.kicad_sym\nLME49600\n\naudio buffer amplifier', 'pins':[
            Pin(num='1',name='BW',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='IN',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='V-',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='V+',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MA12040', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MA12040'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.45x5.45mm'], 'footprint':'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.45x5.45mm', 'keywords':'integrated class d amplifier', 'description':'', 'datasheet':'https://www.infineon.com/dgdl/Infineon-MA12040-DS-v01_00-EN.pdf?fileId=5546d46264a8de7e0164b7467a3d617c', 'search_text':'/usr/share/kicad/symbols/Amplifier_Audio.kicad_sym\nMA12040\n\nintegrated class d amplifier', 'pins':[
            Pin(num='1',name='PVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='OUT0B',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='OUT0B',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='CF0BN',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='PVSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='PVSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='~{CLIP}',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='~{ERROR}',func=pin_types.OUTPUT,unit=1),
            Pin(num='17',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='CMSE',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='AVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PVSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='CREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='IN0A',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='IN0B',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='IN1A',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='IN1B',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='AVSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='27',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='28',name='AD0',func=pin_types.INPUT,unit=1),
            Pin(num='29',name='AD1',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='CF0AN',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='CLKM/S',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='CLKIO',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='~{ENABLE}',func=pin_types.INPUT,unit=1),
            Pin(num='34',name='~{MUTE}',func=pin_types.INPUT,unit=1),
            Pin(num='35',name='PVSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='PVSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='CF1BN',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='OUT1B',func=pin_types.OUTPUT,unit=1),
            Pin(num='39',name='OUT1B',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='OUT0A',func=pin_types.OUTPUT,unit=1),
            Pin(num='40',name='CF1BP',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='PVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='42',name='PVDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='CF1AP',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='OUT1A',func=pin_types.OUTPUT,unit=1),
            Pin(num='45',name='OUT1A',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='CF1AN',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='PVSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='PVSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='NC',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='OUT0A',func=pin_types.PASSIVE,unit=1),
            Pin(num='50',name='MSEL1',func=pin_types.INPUT,unit=1),
            Pin(num='51',name='MSEL0',func=pin_types.INPUT,unit=1),
            Pin(num='52',name='CGD1N',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='CGD1P',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='VGDC',func=pin_types.PASSIVE,unit=1),
            Pin(num='55',name='DVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='56',name='CDC',func=pin_types.PASSIVE,unit=1),
            Pin(num='57',name='CFDCP',func=pin_types.PASSIVE,unit=1),
            Pin(num='58',name='CFDCN',func=pin_types.PASSIVE,unit=1),
            Pin(num='59',name='DVSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='CF0AP',func=pin_types.PASSIVE,unit=1),
            Pin(num='60',name='CGD0P',func=pin_types.PASSIVE,unit=1),
            Pin(num='61',name='CGD0N',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='CFGDP',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='CFGDN',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='NC',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='PVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='PVDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='CF0BP',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MA12040P', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MA12040P'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.45x5.45mm'], 'footprint':'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.45x5.45mm', 'keywords':'integrated class d amplifier', 'description':'', 'datasheet':'https://www.infineon.com/dgdl/Infineon-MA12040P-DS-v01_00-EN.pdf?fileId=5546d46264a8de7e0164b74ff0e561a2', 'search_text':'/usr/share/kicad/symbols/Amplifier_Audio.kicad_sym\nMA12040P\n\nintegrated class d amplifier', 'pins':[
            Pin(num='1',name='PVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='OUT0B',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='OUT0B',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='CF0BN',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='PVSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='PVSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='~{CLIP}',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='~{ERROR}',func=pin_types.OUTPUT,unit=1),
            Pin(num='17',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='CMSE',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='AVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PVSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='CREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='SCLK',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='WS',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='SD0',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='SD1',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='AVSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='27',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='28',name='AD0',func=pin_types.INPUT,unit=1),
            Pin(num='29',name='AD1',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='CF0AN',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='CLKM/S',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='CLK',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='~{ENABLE}',func=pin_types.INPUT,unit=1),
            Pin(num='34',name='~{MUTE}',func=pin_types.INPUT,unit=1),
            Pin(num='35',name='PVSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='PVSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='CF1BN',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='OUT1B',func=pin_types.OUTPUT,unit=1),
            Pin(num='39',name='OUT1B',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='OUT0A',func=pin_types.OUTPUT,unit=1),
            Pin(num='40',name='CF1BP',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='PVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='42',name='PVDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='CF1AP',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='OUT1A',func=pin_types.OUTPUT,unit=1),
            Pin(num='45',name='OUT1A',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='CF1AN',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='PVSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='PVSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='NC',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='OUT0A',func=pin_types.PASSIVE,unit=1),
            Pin(num='50',name='MSEL1',func=pin_types.INPUT,unit=1),
            Pin(num='51',name='MSEL0',func=pin_types.INPUT,unit=1),
            Pin(num='52',name='CGD1N',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='CGD1P',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='VGDC',func=pin_types.PASSIVE,unit=1),
            Pin(num='55',name='DVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='56',name='CDC',func=pin_types.PASSIVE,unit=1),
            Pin(num='57',name='CFDCP',func=pin_types.PASSIVE,unit=1),
            Pin(num='58',name='CFDCN',func=pin_types.PASSIVE,unit=1),
            Pin(num='59',name='DVSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='CF0AP',func=pin_types.PASSIVE,unit=1),
            Pin(num='60',name='CGD0P',func=pin_types.PASSIVE,unit=1),
            Pin(num='61',name='CGD0N',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='CFGDP',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='CFGDN',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='NC',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='PVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='PVDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='CF0BP',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MAX9701xTG', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MAX9701xTG'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:TQFN-24-1EP_4x4mm_P0.5mm_EP2.6x2.6mm'], 'footprint':'Package_DFN_QFN:TQFN-24-1EP_4x4mm_P0.5mm_EP2.6x2.6mm', 'keywords':'stereo power amplifier', 'description':'', 'datasheet':'https://datasheets.maximintegrated.com/en/ds/MAX9701.pdf', 'search_text':'/usr/share/kicad/symbols/Amplifier_Audio.kicad_sym\nMAX9701xTG\n\nstereo power amplifier', 'pins':[
            Pin(num='1',name='~{SHDN}',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='SYNC_OUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='12',name='OUTR-',func=pin_types.PWROUT,unit=1),
            Pin(num='13',name='PGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='PVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='OUTR+',func=pin_types.PWROUT,unit=1),
            Pin(num='16',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='17',name='GAIN1',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='GAIN2',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='INR-',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='SYNC',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='INR+',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='INL+',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='INL-',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='4',name='OUTL+',func=pin_types.PWROUT,unit=1),
            Pin(num='5',name='PVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='PGND',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='OUTL-',func=pin_types.PWROUT,unit=1),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='9',name='GND',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MAX9715xTE+', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MAX9715xTE+'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:TQFN-16-1EP_5x5mm_P0.8mm_EP3.1x3.1mm'], 'footprint':'Package_DFN_QFN:TQFN-16-1EP_5x5mm_P0.8mm_EP3.1x3.1mm', 'keywords':'Class-D Stereo', 'description':'', 'datasheet':'https://datasheets.maximintegrated.com/en/ds/MAX9715.pdf', 'search_text':'/usr/share/kicad/symbols/Amplifier_Audio.kicad_sym\nMAX9715xTE+\n\nClass-D Stereo', 'pins':[
            Pin(num='1',name='PGND',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='OUTR-',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='OUTR+',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='PGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='BIAS',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='INR',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='INL',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='PAD',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='OUTL+',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='OUTL-',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='PVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='GAIN',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='~{SHDN}',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='PVDD',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MAX9814', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MAX9814'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:DFN-14-1EP_3x3mm_P0.4mm_EP1.78x2.35mm'], 'footprint':'Package_DFN_QFN:DFN-14-1EP_3x3mm_P0.4mm_EP1.78x2.35mm', 'keywords':'audio microphone amplifier', 'description':'', 'datasheet':'https://datasheets.maximintegrated.com/en/ds/MAX9814.pdf', 'search_text':'/usr/share/kicad/symbols/Amplifier_Audio.kicad_sym\nMAX9814\n\naudio microphone amplifier', 'pins':[
            Pin(num='1',name='CT',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='GAIN',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='BIAS',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='MICBIAS',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='TH',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~{SHDN}',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='CG',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='MICOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='MICIN',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='A/R',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MAX98306xDT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MAX98306xDT'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:TDFN-14-1EP_3x3mm_P0.4mm_EP1.78x2.35mm'], 'footprint':'Package_DFN_QFN:TDFN-14-1EP_3x3mm_P0.4mm_EP1.78x2.35mm', 'keywords':'Class-D stereo amplifier', 'description':'', 'datasheet':'https://datasheets.maximintegrated.com/en/ds/MAX98306.pdf', 'search_text':'/usr/share/kicad/symbols/Amplifier_Audio.kicad_sym\nMAX98306xDT\n\nClass-D stereo amplifier', 'pins':[
            Pin(num='1',name='PGND',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='OUTR+',func=pin_types.PWROUT,unit=1),
            Pin(num='11',name='PVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='PVDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='OUTL+',func=pin_types.PWROUT,unit=1),
            Pin(num='14',name='OUTL-',func=pin_types.PWROUT,unit=1),
            Pin(num='15',name='PGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~{SHDN}',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='INL+',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='INL-',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='GAIN',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='INR-',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='INR+',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='PGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='OUTR-',func=pin_types.PWROUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MAX98396EWB+', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MAX98396EWB+'}), 'ref_prefix':'U', 'fplist':['Package_CSP:Maxim_WLCSP-35_3.0x2.17mm_Layout7x5_P0.4mm_Ball0.27mm_Pad0.25mm'], 'footprint':'Package_CSP:Maxim_WLCSP-35_3.0x2.17mm_Layout7x5_P0.4mm_Ball0.27mm_Pad0.25mm', 'keywords':'digital audio amp i2s tdm class-dg', 'description':'', 'datasheet':'https://datasheets.maximintegrated.com/en/ds/MAX98396.pdf', 'search_text':'/usr/share/kicad/symbols/Amplifier_Audio.kicad_sym\nMAX98396EWB+\n\ndigital audio amp i2s tdm class-dg', 'pins':[
            Pin(num='A1',name='PVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A2',name='PVDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='A3',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='A4',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='A5',name='IRQ',func=pin_types.OPENCOLL,unit=1),
            Pin(num='A6',name='I2C2',func=pin_types.BIDIR,unit=1),
            Pin(num='A7',name='ICC',func=pin_types.BIDIR,unit=1),
            Pin(num='B1',name='OUTN',func=pin_types.OUTPUT,unit=1),
            Pin(num='B2',name='OUTN',func=pin_types.OUTPUT,unit=1),
            Pin(num='B3',name='OUTNSNS',func=pin_types.OUTPUT,unit=1),
            Pin(num='B4',name='DVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='B5',name='DVDDIO',func=pin_types.PWRIN,unit=1),
            Pin(num='B6',name='ADDR',func=pin_types.INPUT,unit=1),
            Pin(num='B7',name='I2C1',func=pin_types.BIDIR,unit=1),
            Pin(num='C1',name='PGND',func=pin_types.PWRIN,unit=1),
            Pin(num='C2',name='PGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='C3',name='PGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='C4',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='C5',name='DGND',func=pin_types.PWRIN,unit=1),
            Pin(num='C6',name='DGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='C7',name='DOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='D1',name='OUTP',func=pin_types.OUTPUT,unit=1),
            Pin(num='D2',name='OUTP',func=pin_types.OUTPUT,unit=1),
            Pin(num='D3',name='OUTPSNS',func=pin_types.OUTPUT,unit=1),
            Pin(num='D4',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='D5',name='AGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='D6',name='LV_EN',func=pin_types.OPENCOLL,unit=1),
            Pin(num='D7',name='DIN',func=pin_types.INPUT,unit=1),
            Pin(num='E1',name='PVDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='E2',name='PVDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='E3',name='VREFC',func=pin_types.PASSIVE,unit=1),
            Pin(num='E4',name='VBAT',func=pin_types.PASSIVE,unit=1),
            Pin(num='E5',name='AGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='E6',name='LRCLK',func=pin_types.INPUT,unit=1),
            Pin(num='E7',name='BCLK',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MAX9850xTI', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MAX9850xTI'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:TQFN-28-1EP_5x5mm_P0.5mm_EP3.25x3.25mm_ThermalVias'], 'footprint':'Package_DFN_QFN:TQFN-28-1EP_5x5mm_P0.5mm_EP3.25x3.25mm_ThermalVias', 'keywords':'audio ampflifier stereo i2s', 'description':'', 'datasheet':'https://datasheets.maximintegrated.com/en/ds/MAX9850.pdf', 'search_text':'/usr/share/kicad/symbols/Amplifier_Audio.kicad_sym\nMAX9850xTI\n\naudio ampflifier stereo i2s', 'pins':[
            Pin(num='1',name='LRCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='INL',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='OUTR',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='OUTL',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='REF',func=pin_types.PWROUT,unit=1),
            Pin(num='14',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='NREG',func=pin_types.PWROUT,unit=1),
            Pin(num='16',name='PREG',func=pin_types.PWROUT,unit=1),
            Pin(num='17',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='HPR',func=pin_types.OUTPUT,unit=1),
            Pin(num='19',name='HPL',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='BCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='SVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='HPS',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='PVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='C1N',func=pin_types.PASSIVE,unit=1),
            Pin(num='24',name='PGND',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='C1P',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='PVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='27',name='SCL',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='AGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='SDIN',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='DVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='MCLK',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='DGND',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='ADD',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='GPIO',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='INR',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'OPA1622', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'OPA1622'}), 'ref_prefix':'U', 'fplist':['Package_SON:Texas_S-PVSON-N10'], 'footprint':'Package_SON:Texas_S-PVSON-N10', 'keywords':'dual opamp audio', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/opa1622.pdf', 'search_text':'/usr/share/kicad/symbols/Amplifier_Audio.kicad_sym\nOPA1622\n\ndual opamp audio', 'pins':[
            Pin(num='1',name='+',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='-',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='EN',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='+',func=pin_types.INPUT,unit=2),
            Pin(num='6',name='-',func=pin_types.INPUT,unit=2),
            Pin(num='7',name='~',func=pin_types.OUTPUT,unit=2),
            Pin(num='11',name='V-',func=pin_types.PASSIVE,unit=3),
            Pin(num='2',name='V+',func=pin_types.PWRIN,unit=3),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=3),
            Pin(num='4',name='V-',func=pin_types.PWRIN,unit=3)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['1', '8', '9', '10']},{'label': 'uB', 'num': 2, 'pin_nums': ['7', '5', '6']},{'label': 'uC', 'num': 3, 'pin_nums': ['11', '3', '2', '4']}] }),
        Part(**{ 'name':'PAM8301', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PAM8301'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23-6'], 'footprint':'Package_TO_SOT_SMD:SOT-23-6', 'keywords':'audio amplifier class d', 'description':'', 'datasheet':'https://www.diodes.com/assets/Datasheets/products_inactive_data/PAM8301.pdf', 'search_text':'/usr/share/kicad/symbols/Amplifier_Audio.kicad_sym\nPAM8301\n\naudio amplifier class d', 'pins':[
            Pin(num='1',name='OUT-',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='IN',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='~{SD}',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='OUT+',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PAM8302AAD', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PAM8302AAD'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'audio amplifier class d', 'description':'', 'datasheet':'https://www.diodes.com/assets/Datasheets/PAM8302A.pdf', 'search_text':'/usr/share/kicad/symbols/Amplifier_Audio.kicad_sym\nPAM8302AAD\n\naudio amplifier class d', 'pins':[
            Pin(num='1',name='~{SD}',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='3',name='IN+',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='IN-',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='OUT+',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='OUT-',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PAM8302AAY', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PAM8302AAY'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:DFN-8-1EP_3x3mm_P0.65mm_EP1.55x2.4mm'], 'footprint':'Package_DFN_QFN:DFN-8-1EP_3x3mm_P0.65mm_EP1.55x2.4mm', 'keywords':'audio amplifier class d', 'description':'', 'datasheet':'https://www.diodes.com/assets/Datasheets/PAM8302A.pdf', 'search_text':'/usr/share/kicad/symbols/Amplifier_Audio.kicad_sym\nPAM8302AAY\n\naudio amplifier class d', 'pins':[
            Pin(num='1',name='~{SD}',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='3',name='IN+',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='IN-',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='OUT+',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='OUT-',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PAM8403D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PAM8403D'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOP-16_3.9x9.9mm_P1.27mm'], 'footprint':'Package_SO:SOP-16_3.9x9.9mm_P1.27mm', 'keywords':'audio amplifier class d', 'description':'', 'datasheet':'https://www.diodes.com/assets/Datasheets/products_inactive_data/PAM8403.pdf', 'search_text':'/usr/share/kicad/symbols/Amplifier_Audio.kicad_sym\nPAM8403D\n\naudio amplifier class d', 'pins':[
            Pin(num='1',name='LOUT+',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='INR',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='~{SHDN}',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='PVDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='ROUT-',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='PGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='16',name='ROUT+',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='PGND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='LOUT-',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='PVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='~{MUTE}',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='INL',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VREF',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PAM8406D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PAM8406D'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOP-16_3.9x9.9mm_P1.27mm'], 'footprint':'Package_SO:SOP-16_3.9x9.9mm_P1.27mm', 'keywords':'audio amplifier class d or class ab', 'description':'', 'datasheet':'https://www.diodes.com/assets/Datasheets/PAM8406.pdf', 'search_text':'/usr/share/kicad/symbols/Amplifier_Audio.kicad_sym\nPAM8406D\n\naudio amplifier class d or class ab', 'pins':[
            Pin(num='1',name='+OUT_L',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='INR',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='~{SHND}',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='PVDDR',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='-OUT_R',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='PGNDR',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='+OUT_R',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='PGNDL',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='-OUT_L',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='PVDDL',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='~{MUTE}',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='INL',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='VREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='MODE',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SSM2017P', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SSM2017P'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-8_W7.62mm'], 'footprint':'Package_DIP:DIP-8_W7.62mm', 'keywords':'audio preamplifier', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/obsolete-data-sheets/139484016SSM2017.pdf', 'search_text':'/usr/share/kicad/symbols/Amplifier_Audio.kicad_sym\nSSM2017P\n\naudio preamplifier', 'pins':[
            Pin(num='1',name='RG1',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='-',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='+',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='V-',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='REF',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='V+',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='RG2',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SSM2018', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SSM2018'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-16_W7.62mm'], 'footprint':'Package_DIP:DIP-16_W7.62mm', 'keywords':'audio VCA', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/SSM2018.pdf', 'search_text':'/usr/share/kicad/symbols/Amplifier_Audio.kicad_sym\nSSM2018\n\naudio VCA', 'pins':[
            Pin(num='9',name='COMP3',func=pin_types.PASSIVE),
            Pin(num='1',name='+I1-G',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='V-',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VC',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='MODE',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='VG',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='BAL',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='V1-G',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='V+',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='-IG',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='-I1-G',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='COMP1',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='+IN',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='-IN',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='COMP2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SSM2120', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SSM2120'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-22_W7.62mm'], 'footprint':'Package_DIP:DIP-22_W7.62mm', 'keywords':'audio VCA', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/obsolete-data-sheets/105738070SSM2120.pdf', 'search_text':'/usr/share/kicad/symbols/Amplifier_Audio.kicad_sym\nSSM2120\n\naudio VCA', 'pins':[
            Pin(num='4',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='+',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='CFT',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='-',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='IN',func=pin_types.INPUT,unit=1),
            Pin(num='1',name='THRESH',func=pin_types.INPUT,unit=2),
            Pin(num='2',name='LOGAV',func=pin_types.INPUT,unit=2),
            Pin(num='3',name='CONOUT',func=pin_types.INPUT,unit=2),
            Pin(num='9',name='RECIN',func=pin_types.INPUT,unit=2),
            Pin(num='16',name='IN',func=pin_types.INPUT,unit=3),
            Pin(num='17',name='-',func=pin_types.INPUT,unit=3),
            Pin(num='18',name='CFT',func=pin_types.INPUT,unit=3),
            Pin(num='19',name='+',func=pin_types.INPUT,unit=3),
            Pin(num='20',name='~',func=pin_types.OUTPUT,unit=3),
            Pin(num='12',name='THRESH',func=pin_types.INPUT,unit=4),
            Pin(num='13',name='LOGAV',func=pin_types.INPUT,unit=4),
            Pin(num='14',name='CONOUT',func=pin_types.INPUT,unit=4),
            Pin(num='15',name='RECIN',func=pin_types.INPUT,unit=4),
            Pin(num='10',name='IREF',func=pin_types.INPUT,unit=5),
            Pin(num='11',name='V-',func=pin_types.PWRIN,unit=5),
            Pin(num='21',name='V+',func=pin_types.PWRIN,unit=5),
            Pin(num='22',name='GND',func=pin_types.PWRIN,unit=5)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['7', '5', '4', '8', '6']},{'label': 'uB', 'num': 2, 'pin_nums': ['9', '3', '2', '1']},{'label': 'uC', 'num': 3, 'pin_nums': ['16', '18', '20', '17', '19']},{'label': 'uD', 'num': 4, 'pin_nums': ['12', '14', '15', '13']},{'label': 'uE', 'num': 5, 'pin_nums': ['22', '11', '10', '21']}] }),
        Part(**{ 'name':'SSM2122', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SSM2122'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-16_W7.62mm'], 'footprint':'Package_DIP:DIP-16_W7.62mm', 'keywords':'audio VCA', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/obsolete-data-sheets/105738070SSM2120.pdf', 'search_text':'/usr/share/kicad/symbols/Amplifier_Audio.kicad_sym\nSSM2122\n\naudio VCA', 'pins':[
            Pin(num='2',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='+',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='CFT',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='-',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='IN',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='IN',func=pin_types.INPUT,unit=2),
            Pin(num='11',name='-',func=pin_types.INPUT,unit=2),
            Pin(num='12',name='CFT',func=pin_types.INPUT,unit=2),
            Pin(num='13',name='+',func=pin_types.INPUT,unit=2),
            Pin(num='14',name='~',func=pin_types.OUTPUT,unit=2),
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=3),
            Pin(num='15',name='V+',func=pin_types.PWRIN,unit=3),
            Pin(num='16',name='GND',func=pin_types.PASSIVE,unit=3),
            Pin(num='7',name='IREF',func=pin_types.INPUT,unit=3),
            Pin(num='8',name='V-',func=pin_types.PWRIN,unit=3),
            Pin(num='9',name='GND',func=pin_types.PASSIVE,unit=3)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['4', '6', '2', '3', '5']},{'label': 'uB', 'num': 2, 'pin_nums': ['13', '11', '14', '12', '10']},{'label': 'uC', 'num': 3, 'pin_nums': ['16', '15', '7', '9', '8', '1']}] }),
        Part(**{ 'name':'SSM2165', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SSM2165'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'audio microphone preamplifier', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/obsolete-data-sheets/SSM2165.PDF', 'search_text':'/usr/share/kicad/symbols/Amplifier_Audio.kicad_sym\nSSM2165\n\naudio microphone preamplifier', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='VCAIN',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='BUFOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='IN+',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='AVG',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='COMP',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='VOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='V+',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SSM2167', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SSM2167'}), 'ref_prefix':'U', 'fplist':['Package_SO:MSOP-10_3x3mm_P0.5mm'], 'footprint':'Package_SO:MSOP-10_3x3mm_P0.5mm', 'keywords':'audio microphone amplifier', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/SSM2167.pdf', 'search_text':'/usr/share/kicad/symbols/Amplifier_Audio.kicad_sym\nSSM2167\n\naudio microphone amplifier', 'pins':[
            Pin(num='1',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='V+',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='VCAIN',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='~{SD}',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='BUFOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='IN+',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='AVG',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='GATE',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='COMP',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='VOUT',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SSM2211CP', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SSM2211CP'}), 'ref_prefix':'U', 'fplist':['Package_CSP:LFCSP-8-1EP_3x3mm_P0.5mm_EP1.45x1.74mm'], 'footprint':'Package_CSP:LFCSP-8-1EP_3x3mm_P0.5mm_EP1.45x1.74mm', 'keywords':'audio amplifier', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/SSM2211.pdf', 'search_text':'/usr/share/kicad/symbols/Amplifier_Audio.kicad_sym\nSSM2211CP\n\naudio amplifier', 'pins':[
            Pin(num='1',name='SHUTDOWN',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='BYPASS',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='IN+',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='IN-',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='VoutA',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='V+',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='V-',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='VoutB',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='V-',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SSM2211S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SSM2211S'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'audio amplifier', 'description':'', 'datasheet':'https://www.analog.com/media/en/technical-documentation/data-sheets/SSM2211.pdf', 'search_text':'/usr/share/kicad/symbols/Amplifier_Audio.kicad_sym\nSSM2211S\n\naudio amplifier', 'pins':[
            Pin(num='1',name='SHUTDOWN',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='BYPASS',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='IN+',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='IN-',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='VoutA',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='V+',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='V-',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='VoutB',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STK433_Sanyo', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STK433_Sanyo'}), 'ref_prefix':'U', 'fplist':['Package_SIP:Sanyo_STK4xx-15_59.2x8.0mm_P2.54mm'], 'footprint':'Package_SIP:Sanyo_STK4xx-15_59.2x8.0mm_P2.54mm', 'keywords':'audio amplifier 2ch', 'description':'', 'datasheet':'http://datasheet.octopart.com/STK430-Sanyo-datasheet-107060.pdf', 'search_text':'/usr/share/kicad/symbols/Amplifier_Audio.kicad_sym\nSTK433_Sanyo\n\naudio amplifier 2ch', 'pins':[
            Pin(num='1',name='+',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='-',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='V-',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='V-',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='V+',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='~',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='V+',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='11',name='~',func=pin_types.OUTPUT,unit=2),
            Pin(num='12',name='V-',func=pin_types.PWRIN,unit=2),
            Pin(num='13',name='V-',func=pin_types.PWRIN,unit=2),
            Pin(num='14',name='-',func=pin_types.INPUT,unit=2),
            Pin(num='15',name='+',func=pin_types.INPUT,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['1', '2', '4', '8', '6', '5', '3', '7', '9']},{'label': 'uB', 'num': 2, 'pin_nums': ['13', '15', '11', '12', '10', '14']}] }),
        Part(**{ 'name':'STK437_Sanyo', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STK437_Sanyo'}), 'ref_prefix':'U', 'fplist':['Package_SIP:Sanyo_STK4xx-15_78.0x8.0mm_P2.54mm'], 'footprint':'Package_SIP:Sanyo_STK4xx-15_78.0x8.0mm_P2.54mm', 'keywords':'audio amplifier 2ch', 'description':'', 'datasheet':'http://datasheet.octopart.com/STK430-Sanyo-datasheet-107060.pdf', 'search_text':'/usr/share/kicad/symbols/Amplifier_Audio.kicad_sym\nSTK437_Sanyo\n\naudio amplifier 2ch', 'pins':[
            Pin(num='1',name='+',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='-',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='V-',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='V-',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='V+',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='~',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='V+',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='11',name='~',func=pin_types.OUTPUT,unit=2),
            Pin(num='12',name='V-',func=pin_types.PWRIN,unit=2),
            Pin(num='13',name='V-',func=pin_types.PWRIN,unit=2),
            Pin(num='14',name='-',func=pin_types.INPUT,unit=2),
            Pin(num='15',name='+',func=pin_types.INPUT,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['3', '5', '7', '9', '2', '4', '6', '8', '1']},{'label': 'uB', 'num': 2, 'pin_nums': ['11', '13', '15', '12', '14', '10']}] }),
        Part(**{ 'name':'Si8241BB', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Si8241BB'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-16_3.9x9.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-16_3.9x9.9mm_P1.27mm', 'keywords':'class d gate driver', 'description':'', 'datasheet':'https://www.silabs.com/documents/public/data-sheets/Si824x.pdf', 'search_text':'/usr/share/kicad/symbols/Amplifier_Audio.kicad_sym\nSi8241BB\n\nclass d gate driver', 'pins':[
            Pin(num='1',name='PWM',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='VOB',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='VDDB',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='13',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='14',name='GNDA',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VOA',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='3',name='VDDI',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='GNDI',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='DISABLE',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='DT',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='VDDI',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='GNDB',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TAS5825MRHB', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TAS5825MRHB'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:VQFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm'], 'footprint':'Package_DFN_QFN:VQFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'keywords':'Class-D Stereo', 'description':'', 'datasheet':'www.ti.com/lit/ds/symlink/tas5825m.pdf', 'search_text':'/usr/share/kicad/symbols/Amplifier_Audio.kicad_sym\nTAS5825MRHB\n\nClass-D Stereo', 'pins':[
            Pin(num='1',name='BST_A+',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='GPIO1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='GPIO2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='LRCLK',func=pin_types.INPUT,unit=1),
            Pin(num='13',name='SCLK',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='SDIN',func=pin_types.INPUT,unit=1),
            Pin(num='15',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='~{PDN}',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='GVDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='AVDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='OUT_A+',func=pin_types.OUTPUT,unit=1),
            Pin(num='20',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='PVDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='PVDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='23',name='OUT_B+',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='BST_B+',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='PGND',func=pin_types.PWRIN,unit=1),
            Pin(num='26',name='PGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='OUT_B-',func=pin_types.OUTPUT,unit=1),
            Pin(num='28',name='BST_B-',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='BST_A-',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='PVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='OUT_A-',func=pin_types.OUTPUT,unit=1),
            Pin(num='31',name='PGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='32',name='PGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='EP',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='PVDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='DGND',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='DVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VR_DIG',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='ADR',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='GPIO0',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TDA1308', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TDA1308'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'audio amplifier', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/TDA1308.pdf', 'search_text':'/usr/share/kicad/symbols/Amplifier_Audio.kicad_sym\nTDA1308\n\naudio amplifier', 'pins':[
            Pin(num='1',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='-',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='+',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='+',func=pin_types.INPUT,unit=2),
            Pin(num='6',name='-',func=pin_types.INPUT,unit=2),
            Pin(num='7',name='~',func=pin_types.OUTPUT,unit=2),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=3),
            Pin(num='8',name='V+',func=pin_types.PWRIN,unit=3)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['1', '2', '3']},{'label': 'uB', 'num': 2, 'pin_nums': ['5', '6', '7']},{'label': 'uC', 'num': 3, 'pin_nums': ['4', '8']}] }),
        Part(**{ 'name':'TDA2003', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TDA2003'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_THT:TO-220-5_P3.4x3.7mm_StaggerOdd_Lead3.8mm_Vertical'], 'footprint':'Package_TO_SOT_THT:TO-220-5_P3.4x3.7mm_StaggerOdd_Lead3.8mm_Vertical', 'keywords':'audio amplifier', 'description':'', 'datasheet':'http://www.st.com/resource/en/datasheet/cd00000123.pdf', 'search_text':'/usr/share/kicad/symbols/Amplifier_Audio.kicad_sym\nTDA2003\n\naudio amplifier', 'pins':[
            Pin(num='1',name='+',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='-',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='V+',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TDA2005', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TDA2005'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_THT:TO-220-11_P3.4x5.08mm_StaggerOdd_Lead4.85mm_Vertical'], 'footprint':'Package_TO_SOT_THT:TO-220-11_P3.4x5.08mm_StaggerOdd_Lead4.85mm_Vertical', 'keywords':'audio amplifier', 'description':'', 'datasheet':'http://www.st.com/resource/en/datasheet/cd00000124.pdf', 'search_text':'/usr/share/kicad/symbols/Amplifier_Audio.kicad_sym\nTDA2005\n\naudio amplifier', 'pins':[
            Pin(num='1',name='+',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='BOOT',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='-',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='SVRR',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='-',func=pin_types.INPUT,unit=2),
            Pin(num='5',name='+',func=pin_types.INPUT,unit=2),
            Pin(num='7',name='BOOT',func=pin_types.PASSIVE,unit=2),
            Pin(num='8',name='~',func=pin_types.OUTPUT,unit=2),
            Pin(num='6',name='GND',func=pin_types.PWRIN,unit=3),
            Pin(num='9',name='V+',func=pin_types.PWRIN,unit=3)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['1', '2', '10', '11', '3']},{'label': 'uB', 'num': 2, 'pin_nums': ['5', '7', '4', '8']},{'label': 'uC', 'num': 3, 'pin_nums': ['9', '6']}] }),
        Part(**{ 'name':'TDA2030', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TDA2030'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_THT:TO-220-5_P3.4x3.7mm_StaggerOdd_Lead3.8mm_Vertical'], 'footprint':'Package_TO_SOT_THT:TO-220-5_P3.4x3.7mm_StaggerOdd_Lead3.8mm_Vertical', 'keywords':'audio amplifier', 'description':'', 'datasheet':'http://www.st.com/resource/en/datasheet/cd00000128.pdf', 'search_text':'/usr/share/kicad/symbols/Amplifier_Audio.kicad_sym\nTDA2030\n\naudio amplifier', 'pins':[
            Pin(num='1',name='+',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='-',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='-Vs',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='+Vs',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TDA7052A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TDA7052A'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'audio amplifier', 'description':'', 'datasheet':'http://www.nxp.com/docs/en/data-sheet/TDA7052A_AT.pdf', 'search_text':'/usr/share/kicad/symbols/Amplifier_Audio.kicad_sym\nTDA7052A\n\naudio amplifier', 'pins':[
            Pin(num='1',name='VP',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='+',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='V',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='~',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TDA7264', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TDA7264'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_THT:TO-220-8_Vertical'], 'footprint':'Package_TO_SOT_THT:TO-220-8_Vertical', 'keywords':'audio amplifier 2ch', 'description':'', 'datasheet':'http://www.st.com/resource/en/datasheet/tda7264.pdf', 'search_text':'/usr/share/kicad/symbols/Amplifier_Audio.kicad_sym\nTDA7264\n\naudio amplifier 2ch', 'pins':[
            Pin(num='1',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='MUTE',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='IN',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='~',func=pin_types.OUTPUT,unit=2),
            Pin(num='6',name='IN',func=pin_types.INPUT,unit=2),
            Pin(num='2',name='V+',func=pin_types.PWRIN,unit=3),
            Pin(num='5',name='V-',func=pin_types.PWRIN,unit=3)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['1', '8', '7', '4']},{'label': 'uB', 'num': 2, 'pin_nums': ['6', '3']},{'label': 'uC', 'num': 3, 'pin_nums': ['5', '2']}] }),
        Part(**{ 'name':'TDA7265', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TDA7265'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_THT:TO-220-11_P3.4x5.08mm_StaggerOdd_Lead4.85mm_Vertical'], 'footprint':'Package_TO_SOT_THT:TO-220-11_P3.4x5.08mm_StaggerOdd_Lead4.85mm_Vertical', 'keywords':'audio amplifier 2ch', 'description':'', 'datasheet':'http://www.st.com/resource/en/datasheet/tda7265.pdf', 'search_text':'/usr/share/kicad/symbols/Amplifier_Audio.kicad_sym\nTDA7265\n\naudio amplifier 2ch', 'pins':[
            Pin(num='10',name='-',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='+',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='MUTE',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='~',func=pin_types.OUTPUT,unit=2),
            Pin(num='7',name='+',func=pin_types.INPUT,unit=2),
            Pin(num='8',name='-',func=pin_types.INPUT,unit=2),
            Pin(num='1',name='V-',func=pin_types.PWRIN,unit=3),
            Pin(num='3',name='V+',func=pin_types.PWRIN,unit=3),
            Pin(num='6',name='V-',func=pin_types.PASSIVE,unit=3)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['9', '2', '10', '5', '11']},{'label': 'uB', 'num': 2, 'pin_nums': ['4', '7', '8']},{'label': 'uC', 'num': 3, 'pin_nums': ['3', '1', '6']}] }),
        Part(**{ 'name':'TDA7266', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TDA7266'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_THT:TO-220-15_P2.54x2.54mm_StaggerOdd_Lead4.58mm_Vertical'], 'footprint':'Package_TO_SOT_THT:TO-220-15_P2.54x2.54mm_StaggerOdd_Lead4.58mm_Vertical', 'keywords':'audio amplifier 2ch', 'description':'', 'datasheet':'http://www.st.com/resource/en/datasheet/tda7266.pdf', 'search_text':'/usr/share/kicad/symbols/Amplifier_Audio.kicad_sym\nTDA7266\n\naudio amplifier 2ch', 'pins':[
            Pin(num='1',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='11',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='+',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='MUTE',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='STBY',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='+',func=pin_types.INPUT,unit=2),
            Pin(num='14',name='~',func=pin_types.OUTPUT,unit=2),
            Pin(num='15',name='~',func=pin_types.OUTPUT,unit=2),
            Pin(num='13',name='V+',func=pin_types.PASSIVE,unit=3),
            Pin(num='3',name='V+',func=pin_types.PWRIN,unit=3),
            Pin(num='8',name='PG',func=pin_types.PWRIN,unit=3),
            Pin(num='9',name='SG',func=pin_types.PWRIN,unit=3)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['5', '6', '4', '2', '1', '7', '11', '10']},{'label': 'uB', 'num': 2, 'pin_nums': ['12', '14', '15']},{'label': 'uC', 'num': 3, 'pin_nums': ['13', '9', '8', '3']}] }),
        Part(**{ 'name':'TDA7266D', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TDA7266D'}), 'ref_prefix':'U', 'fplist':['Package_SO:HSOP-20-1EP_11.0x15.9mm_P1.27mm_SlugDown'], 'footprint':'Package_SO:HSOP-20-1EP_11.0x15.9mm_P1.27mm_SlugDown', 'keywords':'audio amplifier 2ch', 'description':'', 'datasheet':'http://www.st.com/resource/en/datasheet/tda7266d.pdf', 'search_text':'/usr/share/kicad/symbols/Amplifier_Audio.kicad_sym\nTDA7266D\n\naudio amplifier 2ch', 'pins':[
            Pin(num='12',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='17',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='18',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='4',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='5',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='+',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='MUTE',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='STBY',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='+',func=pin_types.INPUT,unit=2),
            Pin(num='16',name='~',func=pin_types.OUTPUT,unit=2),
            Pin(num='19',name='~',func=pin_types.OUTPUT,unit=2),
            Pin(num='1',name='PG',func=pin_types.PWRIN,unit=3),
            Pin(num='10',name='PG',func=pin_types.PASSIVE,unit=3),
            Pin(num='11',name='PG',func=pin_types.PASSIVE,unit=3),
            Pin(num='13',name='SG',func=pin_types.PWRIN,unit=3),
            Pin(num='15',name='V+',func=pin_types.PASSIVE,unit=3),
            Pin(num='20',name='PG',func=pin_types.PASSIVE,unit=3),
            Pin(num='6',name='V+',func=pin_types.PWRIN,unit=3)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['3', '18', '2', '12', '4', '7', '17', '9', '8', '5']},{'label': 'uB', 'num': 2, 'pin_nums': ['14', '16', '19']},{'label': 'uC', 'num': 3, 'pin_nums': ['13', '11', '10', '20', '6', '15', '1']}] }),
        Part(**{ 'name':'TDA7266M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TDA7266M'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_THT:TO-220-15_P2.54x2.54mm_StaggerOdd_Lead4.58mm_Vertical'], 'footprint':'Package_TO_SOT_THT:TO-220-15_P2.54x2.54mm_StaggerOdd_Lead4.58mm_Vertical', 'keywords':'audio amplifier', 'description':'', 'datasheet':'http://www.st.com/resource/en/datasheet/tda7266m.pdf', 'search_text':'/usr/share/kicad/symbols/Amplifier_Audio.kicad_sym\nTDA7266M\n\naudio amplifier', 'pins':[
            Pin(num='1',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='11',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='12',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='13',name='V+',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='15',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='V+',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='+',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='MUTE',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='STBY',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='PG',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='SG',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TDA7266P', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TDA7266P'}), 'ref_prefix':'U', 'fplist':['Package_SO:ST_PowerSSO-24_SlugDown'], 'footprint':'Package_SO:ST_PowerSSO-24_SlugDown', 'keywords':'audio amplifier 2ch', 'description':'', 'datasheet':'http://www.st.com/resource/en/datasheet/tda7266p.pdf', 'search_text':'/usr/share/kicad/symbols/Amplifier_Audio.kicad_sym\nTDA7266P\n\naudio amplifier 2ch', 'pins':[
            Pin(num='10',name='MUTE',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='STBY',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='13',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='15',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='16',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='21',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='22',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='23',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='4',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='5',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='+',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='17',name='+',func=pin_types.INPUT,unit=2),
            Pin(num='19',name='~',func=pin_types.OUTPUT,unit=2),
            Pin(num='20',name='~',func=pin_types.OUTPUT,unit=2),
            Pin(num='1',name='PG',func=pin_types.PWRIN,unit=3),
            Pin(num='14',name='SG',func=pin_types.PWRIN,unit=3),
            Pin(num='18',name='V+',func=pin_types.PASSIVE,unit=3),
            Pin(num='24',name='PG',func=pin_types.PASSIVE,unit=3),
            Pin(num='7',name='V+',func=pin_types.PWRIN,unit=3)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['16', '3', '5', '4', '13', '11', '15', '6', '10', '22', '9', '2', '21', '12', '8', '23']},{'label': 'uB', 'num': 2, 'pin_nums': ['17', '20', '19']},{'label': 'uC', 'num': 3, 'pin_nums': ['14', '1', '24', '7', '18']}] }),
        Part(**{ 'name':'TDA7293', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TDA7293'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_THT:TO-220-15_P2.54x2.54mm_StaggerOdd_Lead4.58mm_Vertical'], 'footprint':'Package_TO_SOT_THT:TO-220-15_P2.54x2.54mm_StaggerOdd_Lead4.58mm_Vertical', 'keywords':'audio amplifier', 'description':'', 'datasheet':'http://www.st.com/resource/en/datasheet/tda7293.pdf', 'search_text':'/usr/share/kicad/symbols/Amplifier_Audio.kicad_sym\nTDA7293\n\naudio amplifier', 'pins':[
            Pin(num='1',name='SGND',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='MUTE',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='12',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='13',name='+Vs',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='-Vs',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='-',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='+',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='SIG_GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='BOOT',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='+Vs',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='-Vs',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='STBY',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TDA7496', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TDA7496'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_THT:TO-220-15_P2.54x2.54mm_StaggerOdd_Lead4.58mm_Vertical'], 'footprint':'Package_TO_SOT_THT:TO-220-15_P2.54x2.54mm_StaggerOdd_Lead4.58mm_Vertical', 'keywords':'audio amplifier 2ch', 'description':'', 'datasheet':'http://www.st.com/resource/en/datasheet/tda7297.pdf', 'search_text':'/usr/share/kicad/symbols/Amplifier_Audio.kicad_sym\nTDA7496\n\naudio amplifier 2ch', 'pins':[
            Pin(num='10',name='MUTE',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='V',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='O',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='+',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='9',name='STBY',func=pin_types.INPUT,unit=1),
            Pin(num='1',name='+',func=pin_types.INPUT,unit=2),
            Pin(num='14',name='~',func=pin_types.OUTPUT,unit=2),
            Pin(num='2',name='O',func=pin_types.OUTPUT,unit=2),
            Pin(num='7',name='SVR',func=pin_types.PASSIVE,unit=2),
            Pin(num='11',name='PG',func=pin_types.PWRIN,unit=3),
            Pin(num='13',name='V+',func=pin_types.PWRIN,unit=3),
            Pin(num='15',name='PG',func=pin_types.PASSIVE,unit=3),
            Pin(num='8',name='SG',func=pin_types.PWRIN,unit=3)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['4', '9', '5', '6', '10', '3', '12']},{'label': 'uB', 'num': 2, 'pin_nums': ['1', '14', '2', '7']},{'label': 'uC', 'num': 3, 'pin_nums': ['13', '8', '15', '11']}] }),
        Part(**{ 'name':'TFA9879HN', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TFA9879HN'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:HVQFN-24-1EP_4x4mm_P0.5mm_EP2.6x2.6mm_ThermalVias'], 'footprint':'Package_DFN_QFN:HVQFN-24-1EP_4x4mm_P0.5mm_EP2.6x2.6mm_ThermalVias', 'keywords':'Audio Amplifier Class D NXP Semiconductors', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/TFA9879.pdf', 'search_text':'/usr/share/kicad/symbols/Amplifier_Audio.kicad_sym\nTFA9879HN\n\nAudio Amplifier Class D NXP Semiconductors', 'pins':[
            Pin(num='1',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='OUTA',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='GNDP',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='GNDP',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='STABA',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='15',name='TEST2',func=pin_types.INPUT,unit=1),
            Pin(num='16',name='ADSEL1',func=pin_types.INPUT,unit=1),
            Pin(num='17',name='SDI2',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='SCK2',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='LRCK2',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='20',name='SDI1',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='SCK1',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='LRCK1',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='24',name='GNDD',func=pin_types.PWRIN,unit=1),
            Pin(num='25',name='EP',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='TEST1',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='ADSEL2',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='TEST3',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='7',name='VDDP',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='VDDP',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='OUTB',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'THAT151xx08', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'THAT151xx08'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'Audio Preamplifier', 'description':'', 'datasheet':'https://www.thatcorp.com/datashts/THAT_1510-1512_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/Amplifier_Audio.kicad_sym\nTHAT151xx08\n\nAudio Preamplifier', 'pins':[
            Pin(num='1',name='Rg1',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='-In',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='+In',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='V-',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='Ref',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='Out',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='V+',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='Rg2',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'THAT2180', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'THAT2180'}), 'ref_prefix':'U', 'fplist':['Package_SIP:SIP-8_19x3mm_P2.54mm'], 'footprint':'Package_SIP:SIP-8_19x3mm_P2.54mm', 'keywords':'audio vca', 'description':'', 'datasheet':'http://www.thatcorp.com/datashts/THAT_2180-Series_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/Amplifier_Audio.kicad_sym\nTHAT2180\n\naudio vca', 'pins':[
            Pin(num='5',name='V-',func=pin_types.PWRIN),
            Pin(num='6',name='GND',func=pin_types.PWRIN),
            Pin(num='7',name='V+',func=pin_types.PWRIN),
            Pin(num='1',name='-',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='E+',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='E-',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='SYM',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='~',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'THAT2181', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'THAT2181'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'audio vca', 'description':'', 'datasheet':'http://www.thatcorp.com/datashts/THAT_2181-Series_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/Amplifier_Audio.kicad_sym\nTHAT2181\n\naudio vca', 'pins':[
            Pin(num='5',name='V-',func=pin_types.PWRIN),
            Pin(num='6',name='GND',func=pin_types.PWRIN),
            Pin(num='7',name='V+',func=pin_types.PWRIN),
            Pin(num='1',name='-',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='E+',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='E-',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='SYM',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='~',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TPA3251', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TPA3251'}), 'ref_prefix':'U', 'fplist':['Package_SO:HTSSOP-44_6.1x14mm_P0.635mm_TopEP4.14x7.01mm'], 'footprint':'Package_SO:HTSSOP-44_6.1x14mm_P0.635mm_TopEP4.14x7.01mm', 'keywords':'stereo class d amplifier', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/tpa3251.pdf', 'search_text':'/usr/share/kicad/symbols/Amplifier_Audio.kicad_sym\nTPA3251\n\nstereo class d amplifier', 'pins':[
            Pin(num='1',name='GVDD_AB',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='OSC_IOP',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='DVDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='AVDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='C_START',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='VBG',func=pin_types.PASSIVE,unit=1),
            Pin(num='25',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='33',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='34',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='35',name='OUT_B',func=pin_types.OUTPUT,unit=1),
            Pin(num='36',name='PVDD_AB',func=pin_types.PWRIN,unit=1),
            Pin(num='37',name='PVDD_AB',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='PVDD_AB',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='OUT_A',func=pin_types.OUTPUT,unit=1),
            Pin(num='40',name='OUT_A',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='BST_B',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='BST_A',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='INPUT_A',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='INPUT_B',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='OC_ADJ',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='FREQ_ADJ',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='OSC_IOM',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='INPUT_C',func=pin_types.INPUT,unit=2),
            Pin(num='17',name='INPUT_D',func=pin_types.INPUT,unit=2),
            Pin(num='18',name='~{RESET}',func=pin_types.INPUT,unit=2),
            Pin(num='19',name='~{FAULT}',func=pin_types.OPENCOLL,unit=2),
            Pin(num='21',name='~{CLIP_OTW}',func=pin_types.OPENCOLL,unit=2),
            Pin(num='22',name='GVDD_CD',func=pin_types.PWRIN,unit=2),
            Pin(num='23',name='BST_D',func=pin_types.PASSIVE,unit=2),
            Pin(num='24',name='BST_C',func=pin_types.PASSIVE,unit=2),
            Pin(num='27',name='OUT_D',func=pin_types.OUTPUT,unit=2),
            Pin(num='28',name='OUT_D',func=pin_types.PASSIVE,unit=2),
            Pin(num='29',name='PVDD_CD',func=pin_types.PWRIN,unit=2),
            Pin(num='3',name='M1',func=pin_types.INPUT,unit=2),
            Pin(num='30',name='PVDD_CD',func=pin_types.PASSIVE,unit=2),
            Pin(num='31',name='PVDD_CD',func=pin_types.PASSIVE,unit=2),
            Pin(num='32',name='OUT_C',func=pin_types.OUTPUT,unit=2),
            Pin(num='4',name='M2',func=pin_types.INPUT,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['1', '42', '9', '34', '12', '35', '43', '14', '37', '15', '36', '44', '13', '10', '2', '38', '5', '25', '20', '6', '26', '40', '39', '7', '33', '41', '8', '11']},{'label': 'uB', 'num': 2, 'pin_nums': ['22', '19', '17', '24', '28', '3', '4', '18', '21', '16', '23', '30', '27', '29', '31', '32']}] }),
        Part(**{ 'name':'TPA6110A2DGN', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TPA6110A2DGN'}), 'ref_prefix':'U', 'fplist':['Package_SO:HVSSOP-8-1EP_3x3mm_P0.65mm_EP1.57x1.89mm'], 'footprint':'Package_SO:HVSSOP-8-1EP_3x3mm_P0.65mm_EP1.57x1.89mm', 'keywords':'audio amplifier headphone', 'description':'', 'datasheet':'https://www.ti.com/lit/ds/symlink/tpa6110a2.pdf', 'search_text':'/usr/share/kicad/symbols/Amplifier_Audio.kicad_sym\nTPA6110A2DGN\n\naudio amplifier headphone', 'pins':[
            Pin(num='1',name='BYPASS',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='SHDN',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='IN2-',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='VO2',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VO1',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='IN1-',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TPA6132A2RTE', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TPA6132A2RTE'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:WQFN-16-1EP_3x3mm_P0.5mm_EP1.6x1.6mm_ThermalVias'], 'footprint':'Package_DFN_QFN:WQFN-16-1EP_3x3mm_P0.5mm_EP1.6x1.6mm_ThermalVias', 'keywords':'DirectPath audio amplifier Stereo', 'description':'', 'datasheet':'https://www.ti.com/lit/ds/symlink/tpa6132a2.pdf', 'search_text':'/usr/share/kicad/symbols/Amplifier_Audio.kicad_sym\nTPA6132A2RTE\n\nDirectPath audio amplifier Stereo', 'pins':[
            Pin(num='1',name='INL-',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='PGND',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='CPP',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='HPVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='EN',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='SGND',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='OUTL',func=pin_types.OUTPUT,unit=1),
            Pin(num='17',name='EP',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='INL+',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='INR+',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='INR-',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='OUTR',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='G0',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='G1',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='HPVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='CPN',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TPA6203A1DGN', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TPA6203A1DGN'}), 'ref_prefix':'U', 'fplist':['Package_SO:MSOP-8-1EP_3x3mm_P0.65mm_EP1.95x2.15mm_ThermalVias'], 'footprint':'Package_SO:MSOP-8-1EP_3x3mm_P0.65mm_EP1.95x2.15mm_ThermalVias', 'keywords':'Differential audio amplifier Mono', 'description':'', 'datasheet':'https://www.ti.com/lit/ds/symlink/tpa6203a1.pdf', 'search_text':'/usr/share/kicad/symbols/Amplifier_Audio.kicad_sym\nTPA6203A1DGN\n\nDifferential audio amplifier Mono', 'pins':[
            Pin(num='1',name='~{SHUTDOWN}',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='BYPASS',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='IN+',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='IN-',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='V_{O+}',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='V_{DD}',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='V_{O-}',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IR4311', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IR4311'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Infineon_PQFN-22-15-4EP_6x5mm_P0.65mm', 'Package_DFN_QFN:Infineon_PQFN-22-15-4EP_6x5mm_P0.65mm'], 'footprint':'Package_DFN_QFN:Infineon_PQFN-22-15-4EP_6x5mm_P0.65mm', 'keywords':'integrated class d amplifier', 'description':'', 'datasheet':'https://www.infineon.com/dgdl/ir4301.pdf?fileId=5546d462533600a4015355d5fc691819', 'search_text':'/usr/share/kicad/symbols/Amplifier_Audio.kicad_sym\nIR4311\n\nintegrated class d amplifier', 'pins':[
            Pin(num='1',name='VAA',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='VN',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VS',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='VP',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VB',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='CSH',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='COM',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='IN+',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='IN-',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='COMP',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='CSD',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='COM',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IR4312', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IR4312'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Infineon_PQFN-44-31-5EP_7x7mm_P0.5mm', 'Package_DFN_QFN:Infineon_PQFN-44-31-5EP_7x7mm_P0.5mm'], 'footprint':'Package_DFN_QFN:Infineon_PQFN-44-31-5EP_7x7mm_P0.5mm', 'keywords':'integrated class d amplifier 2ch', 'description':'', 'datasheet':'https://www.infineon.com/dgdl/ir4302.pdf?fileId=5546d462533600a4015355d602a9181d', 'search_text':'/usr/share/kicad/symbols/Amplifier_Audio.kicad_sym\nIR4312\n\nintegrated class d amplifier 2ch', 'pins':[
            Pin(num='1',name='CLIP',func=pin_types.OPENCOLL,unit=1),
            Pin(num='10',name='COMP1',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='CSD',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='FAULT',func=pin_types.OPENCOLL,unit=1),
            Pin(num='13',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='14',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='COM',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='CSH1',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='VB1',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='VS1',func=pin_types.OUTPUT,unit=1),
            Pin(num='19',name='VP1',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='VS1',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='VN1',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='COM',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='30',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='31',name='COM',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VAA',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='IN+1',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='IN-1',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='COMP2',func=pin_types.OUTPUT,unit=2),
            Pin(num='22',name='VN2',func=pin_types.PWRIN,unit=2),
            Pin(num='23',name='VS2',func=pin_types.OUTPUT,unit=2),
            Pin(num='24',name='VP2',func=pin_types.PWRIN,unit=2),
            Pin(num='25',name='VS2',func=pin_types.PASSIVE,unit=2),
            Pin(num='26',name='VB2',func=pin_types.PWRIN,unit=2),
            Pin(num='27',name='CSH2',func=pin_types.PASSIVE,unit=2),
            Pin(num='3',name='IN-2',func=pin_types.INPUT,unit=2),
            Pin(num='4',name='IN+2',func=pin_types.INPUT,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['29', '11', '5', '1', '6', '30', '7', '8', '31', '10', '12', '9', '13', '17', '18', '20', '15', '21', '19', '16', '28', '14']},{'label': 'uB', 'num': 2, 'pin_nums': ['23', '4', '25', '22', '24', '26', '27', '3', '2']}] }),
        Part(**{ 'name':'IR4321', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IR4321'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Infineon_PQFN-22-15-4EP_6x5mm_P0.65mm', 'Package_DFN_QFN:Infineon_PQFN-22-15-4EP_6x5mm_P0.65mm', 'Package_DFN_QFN:Infineon_PQFN-22-15-4EP_6x5mm_P0.65mm'], 'footprint':'Package_DFN_QFN:Infineon_PQFN-22-15-4EP_6x5mm_P0.65mm', 'keywords':'integrated class d amplifier', 'description':'', 'datasheet':'https://www.infineon.com/dgdl/ir4301.pdf?fileId=5546d462533600a4015355d5fc691819', 'search_text':'/usr/share/kicad/symbols/Amplifier_Audio.kicad_sym\nIR4321\n\nintegrated class d amplifier', 'pins':[
            Pin(num='1',name='VAA',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='VN',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='VS',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='VP',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='VB',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='CSH',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='COM',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='IN+',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='IN-',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='COMP',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='CSD',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='COM',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'IR4322', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'IR4322'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:Infineon_PQFN-44-31-5EP_7x7mm_P0.5mm', 'Package_DFN_QFN:Infineon_PQFN-44-31-5EP_7x7mm_P0.5mm', 'Package_DFN_QFN:Infineon_PQFN-44-31-5EP_7x7mm_P0.5mm'], 'footprint':'Package_DFN_QFN:Infineon_PQFN-44-31-5EP_7x7mm_P0.5mm', 'keywords':'integrated class d amplifier 2ch', 'description':'', 'datasheet':'https://www.infineon.com/dgdl/ir4302.pdf?fileId=5546d462533600a4015355d602a9181d', 'search_text':'/usr/share/kicad/symbols/Amplifier_Audio.kicad_sym\nIR4322\n\nintegrated class d amplifier 2ch', 'pins':[
            Pin(num='1',name='CLIP',func=pin_types.OPENCOLL,unit=1),
            Pin(num='10',name='COMP1',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='CSD',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='FAULT',func=pin_types.OPENCOLL,unit=1),
            Pin(num='13',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='14',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='COM',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='CSH1',func=pin_types.PASSIVE,unit=1),
            Pin(num='17',name='VB1',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='VS1',func=pin_types.OUTPUT,unit=1),
            Pin(num='19',name='VP1',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='VS1',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='VN1',func=pin_types.PWRIN,unit=1),
            Pin(num='28',name='COM',func=pin_types.PASSIVE,unit=1),
            Pin(num='29',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='30',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='31',name='COM',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VAA',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='IN+1',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='IN-1',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='COMP2',func=pin_types.OUTPUT,unit=2),
            Pin(num='22',name='VN2',func=pin_types.PWRIN,unit=2),
            Pin(num='23',name='VS2',func=pin_types.OUTPUT,unit=2),
            Pin(num='24',name='VP2',func=pin_types.PWRIN,unit=2),
            Pin(num='25',name='VS2',func=pin_types.PASSIVE,unit=2),
            Pin(num='26',name='VB2',func=pin_types.PWRIN,unit=2),
            Pin(num='27',name='CSH2',func=pin_types.PASSIVE,unit=2),
            Pin(num='3',name='IN-2',func=pin_types.INPUT,unit=2),
            Pin(num='4',name='IN+2',func=pin_types.INPUT,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['12', '13', '29', '19', '20', '30', '10', '21', '31', '5', '1', '16', '17', '6', '28', '18', '7', '8', '14', '15', '9', '11']},{'label': 'uB', 'num': 2, 'pin_nums': ['25', '22', '23', '3', '26', '2', '4', '24', '27']}] }),
        Part(**{ 'name':'MA12070', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MA12070'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.45x5.45mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.45x5.45mm'], 'footprint':'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.45x5.45mm', 'keywords':'integrated class d amplifier', 'description':'', 'datasheet':'https://www.infineon.com/dgdl/Infineon-MA12070-DS-v01_00-EN.pdf?fileId=5546d46264a8de7e0164b750002861a5', 'search_text':'/usr/share/kicad/symbols/Amplifier_Audio.kicad_sym\nMA12070\n\nintegrated class d amplifier', 'pins':[
            Pin(num='1',name='PVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='OUT0B',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='OUT0B',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='CF0BN',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='PVSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='PVSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='~{CLIP}',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='~{ERROR}',func=pin_types.OUTPUT,unit=1),
            Pin(num='17',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='CMSE',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='AVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PVSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='CREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='IN0A',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='IN0B',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='IN1A',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='IN1B',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='AVSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='27',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='28',name='AD0',func=pin_types.INPUT,unit=1),
            Pin(num='29',name='AD1',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='CF0AN',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='CLKM/S',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='CLKIO',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='~{ENABLE}',func=pin_types.INPUT,unit=1),
            Pin(num='34',name='~{MUTE}',func=pin_types.INPUT,unit=1),
            Pin(num='35',name='PVSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='PVSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='CF1BN',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='OUT1B',func=pin_types.OUTPUT,unit=1),
            Pin(num='39',name='OUT1B',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='OUT0A',func=pin_types.OUTPUT,unit=1),
            Pin(num='40',name='CF1BP',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='PVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='42',name='PVDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='CF1AP',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='OUT1A',func=pin_types.OUTPUT,unit=1),
            Pin(num='45',name='OUT1A',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='CF1AN',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='PVSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='PVSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='NC',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='OUT0A',func=pin_types.PASSIVE,unit=1),
            Pin(num='50',name='MSEL1',func=pin_types.INPUT,unit=1),
            Pin(num='51',name='MSEL0',func=pin_types.INPUT,unit=1),
            Pin(num='52',name='CGD1N',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='CGD1P',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='VGDC',func=pin_types.PASSIVE,unit=1),
            Pin(num='55',name='DVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='56',name='CDC',func=pin_types.PASSIVE,unit=1),
            Pin(num='57',name='CFDCP',func=pin_types.PASSIVE,unit=1),
            Pin(num='58',name='CFDCN',func=pin_types.PASSIVE,unit=1),
            Pin(num='59',name='DVSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='CF0AP',func=pin_types.PASSIVE,unit=1),
            Pin(num='60',name='CGD0P',func=pin_types.PASSIVE,unit=1),
            Pin(num='61',name='CGD0N',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='CFGDP',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='CFGDN',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='NC',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='PVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='PVDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='CF0BP',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'MA12070P', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'MA12070P'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.45x5.45mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.45x5.45mm'], 'footprint':'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP5.45x5.45mm', 'keywords':'integrated class d amplifier', 'description':'', 'datasheet':'https://www.infineon.com/dgdl/Infineon-MA12070P-DS-v01_00-EN.pdf?fileId=5546d46264a8de7e0164b761f2f261e4', 'search_text':'/usr/share/kicad/symbols/Amplifier_Audio.kicad_sym\nMA12070P\n\nintegrated class d amplifier', 'pins':[
            Pin(num='1',name='PVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='OUT0B',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='OUT0B',func=pin_types.PASSIVE,unit=1),
            Pin(num='12',name='CF0BN',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='PVSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='PVSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='~{CLIP}',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='~{ERROR}',func=pin_types.OUTPUT,unit=1),
            Pin(num='17',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='CMSE',func=pin_types.PASSIVE,unit=1),
            Pin(num='19',name='AVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PVSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='20',name='CREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='21',name='SCLK',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='WS',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='SD0',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='SD1',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='AVSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='27',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='28',name='AD0',func=pin_types.INPUT,unit=1),
            Pin(num='29',name='AD1',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='CF0AN',func=pin_types.PASSIVE,unit=1),
            Pin(num='30',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='CLKM/S',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='CLK',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='~{ENABLE}',func=pin_types.INPUT,unit=1),
            Pin(num='34',name='~{MUTE}',func=pin_types.INPUT,unit=1),
            Pin(num='35',name='PVSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='36',name='PVSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='CF1BN',func=pin_types.PASSIVE,unit=1),
            Pin(num='38',name='OUT1B',func=pin_types.OUTPUT,unit=1),
            Pin(num='39',name='OUT1B',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='OUT0A',func=pin_types.OUTPUT,unit=1),
            Pin(num='40',name='CF1BP',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='PVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='42',name='PVDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='43',name='CF1AP',func=pin_types.PASSIVE,unit=1),
            Pin(num='44',name='OUT1A',func=pin_types.OUTPUT,unit=1),
            Pin(num='45',name='OUT1A',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='CF1AN',func=pin_types.PASSIVE,unit=1),
            Pin(num='47',name='PVSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='48',name='PVSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='49',name='NC',func=pin_types.PASSIVE,unit=1),
            Pin(num='5',name='OUT0A',func=pin_types.PASSIVE,unit=1),
            Pin(num='50',name='MSEL1',func=pin_types.INPUT,unit=1),
            Pin(num='51',name='MSEL0',func=pin_types.INPUT,unit=1),
            Pin(num='52',name='CGD1N',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='CGD1P',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='VGDC',func=pin_types.PASSIVE,unit=1),
            Pin(num='55',name='DVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='56',name='CDC',func=pin_types.PASSIVE,unit=1),
            Pin(num='57',name='CFDCP',func=pin_types.PASSIVE,unit=1),
            Pin(num='58',name='CFDCN',func=pin_types.PASSIVE,unit=1),
            Pin(num='59',name='DVSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='CF0AP',func=pin_types.PASSIVE,unit=1),
            Pin(num='60',name='CGD0P',func=pin_types.PASSIVE,unit=1),
            Pin(num='61',name='CGD0N',func=pin_types.PASSIVE,unit=1),
            Pin(num='62',name='CFGDP',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='CFGDN',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='NC',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='PVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='PVDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='CF0BP',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PAM8302AAS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PAM8302AAS'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'audio amplifier class d', 'description':'', 'datasheet':'https://www.diodes.com/assets/Datasheets/PAM8302A.pdf', 'search_text':'/usr/share/kicad/symbols/Amplifier_Audio.kicad_sym\nPAM8302AAS\n\naudio amplifier class d', 'pins':[
            Pin(num='1',name='~{SD}',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='3',name='IN+',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='IN-',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='OUT+',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='OUT-',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'STK435_Sanyo', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STK435_Sanyo'}), 'ref_prefix':'U', 'fplist':['Package_SIP:Sanyo_STK4xx-15_59.2x8.0mm_P2.54mm', 'Package_SIP:Sanyo_STK4xx-15_59.2x8.0mm_P2.54mm'], 'footprint':'Package_SIP:Sanyo_STK4xx-15_59.2x8.0mm_P2.54mm', 'keywords':'audio amplifier 2ch', 'description':'', 'datasheet':'http://datasheet.octopart.com/STK430-Sanyo-datasheet-107060.pdf', 'search_text':'/usr/share/kicad/symbols/Amplifier_Audio.kicad_sym\nSTK435_Sanyo\n\naudio amplifier 2ch', 'pins':[
            Pin(num='1',name='+',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='-',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='V-',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='V-',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='V+',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='~',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='V+',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='11',name='~',func=pin_types.OUTPUT,unit=2),
            Pin(num='12',name='V-',func=pin_types.PWRIN,unit=2),
            Pin(num='13',name='V-',func=pin_types.PWRIN,unit=2),
            Pin(num='14',name='-',func=pin_types.INPUT,unit=2),
            Pin(num='15',name='+',func=pin_types.INPUT,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['8', '2', '4', '6', '9', '1', '5', '7', '3']},{'label': 'uB', 'num': 2, 'pin_nums': ['10', '14', '11', '13', '12', '15']}] }),
        Part(**{ 'name':'STK436_Sanyo', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STK436_Sanyo'}), 'ref_prefix':'U', 'fplist':['Package_SIP:Sanyo_STK4xx-15_59.2x8.0mm_P2.54mm', 'Package_SIP:Sanyo_STK4xx-15_59.2x8.0mm_P2.54mm', 'Package_SIP:Sanyo_STK4xx-15_59.2x8.0mm_P2.54mm'], 'footprint':'Package_SIP:Sanyo_STK4xx-15_59.2x8.0mm_P2.54mm', 'keywords':'audio amplifier 2ch', 'description':'', 'datasheet':'http://datasheet.octopart.com/STK430-Sanyo-datasheet-107060.pdf', 'search_text':'/usr/share/kicad/symbols/Amplifier_Audio.kicad_sym\nSTK436_Sanyo\n\naudio amplifier 2ch', 'pins':[
            Pin(num='1',name='+',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='-',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='V-',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='V-',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='V+',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='~',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='V+',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='11',name='~',func=pin_types.OUTPUT,unit=2),
            Pin(num='12',name='V-',func=pin_types.PWRIN,unit=2),
            Pin(num='13',name='V-',func=pin_types.PWRIN,unit=2),
            Pin(num='14',name='-',func=pin_types.INPUT,unit=2),
            Pin(num='15',name='+',func=pin_types.INPUT,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['6', '7', '4', '3', '8', '5', '1', '2', '9']},{'label': 'uB', 'num': 2, 'pin_nums': ['12', '10', '15', '13', '11', '14']}] }),
        Part(**{ 'name':'STK439_Sanyo', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STK439_Sanyo'}), 'ref_prefix':'U', 'fplist':['Package_SIP:Sanyo_STK4xx-15_78.0x8.0mm_P2.54mm', 'Package_SIP:Sanyo_STK4xx-15_78.0x8.0mm_P2.54mm'], 'footprint':'Package_SIP:Sanyo_STK4xx-15_78.0x8.0mm_P2.54mm', 'keywords':'audio amplifier 2ch', 'description':'', 'datasheet':'http://datasheet.octopart.com/STK430-Sanyo-datasheet-107060.pdf', 'search_text':'/usr/share/kicad/symbols/Amplifier_Audio.kicad_sym\nSTK439_Sanyo\n\naudio amplifier 2ch', 'pins':[
            Pin(num='1',name='+',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='-',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='V-',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='V-',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='V+',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='~',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='V+',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='11',name='~',func=pin_types.OUTPUT,unit=2),
            Pin(num='12',name='V-',func=pin_types.PWRIN,unit=2),
            Pin(num='13',name='V-',func=pin_types.PWRIN,unit=2),
            Pin(num='14',name='-',func=pin_types.INPUT,unit=2),
            Pin(num='15',name='+',func=pin_types.INPUT,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['9', '7', '4', '3', '6', '8', '2', '5', '1']},{'label': 'uB', 'num': 2, 'pin_nums': ['10', '12', '14', '13', '11', '15']}] }),
        Part(**{ 'name':'STK441_Sanyo', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STK441_Sanyo'}), 'ref_prefix':'U', 'fplist':['Package_SIP:Sanyo_STK4xx-15_78.0x8.0mm_P2.54mm', 'Package_SIP:Sanyo_STK4xx-15_78.0x8.0mm_P2.54mm', 'Package_SIP:Sanyo_STK4xx-15_78.0x8.0mm_P2.54mm'], 'footprint':'Package_SIP:Sanyo_STK4xx-15_78.0x8.0mm_P2.54mm', 'keywords':'audio amplifier 2ch', 'description':'', 'datasheet':'http://datasheet.octopart.com/STK430-Sanyo-datasheet-107060.pdf', 'search_text':'/usr/share/kicad/symbols/Amplifier_Audio.kicad_sym\nSTK441_Sanyo\n\naudio amplifier 2ch', 'pins':[
            Pin(num='1',name='+',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='-',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='V-',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='V-',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='V+',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='~',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='V+',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='11',name='~',func=pin_types.OUTPUT,unit=2),
            Pin(num='12',name='V-',func=pin_types.PWRIN,unit=2),
            Pin(num='13',name='V-',func=pin_types.PWRIN,unit=2),
            Pin(num='14',name='-',func=pin_types.INPUT,unit=2),
            Pin(num='15',name='+',func=pin_types.INPUT,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['6', '1', '7', '4', '3', '8', '5', '2', '9']},{'label': 'uB', 'num': 2, 'pin_nums': ['15', '10', '13', '11', '14', '12']}] }),
        Part(**{ 'name':'STK443_Sanyo', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'STK443_Sanyo'}), 'ref_prefix':'U', 'fplist':['Package_SIP:Sanyo_STK4xx-15_78.0x8.0mm_P2.54mm', 'Package_SIP:Sanyo_STK4xx-15_78.0x8.0mm_P2.54mm', 'Package_SIP:Sanyo_STK4xx-15_78.0x8.0mm_P2.54mm', 'Package_SIP:Sanyo_STK4xx-15_78.0x8.0mm_P2.54mm'], 'footprint':'Package_SIP:Sanyo_STK4xx-15_78.0x8.0mm_P2.54mm', 'keywords':'audio amplifier 2ch', 'description':'', 'datasheet':'http://datasheet.octopart.com/STK430-Sanyo-datasheet-107060.pdf', 'search_text':'/usr/share/kicad/symbols/Amplifier_Audio.kicad_sym\nSTK443_Sanyo\n\naudio amplifier 2ch', 'pins':[
            Pin(num='1',name='+',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='-',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='V-',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='V-',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='~',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='V+',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='~',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='V+',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='~',func=pin_types.PASSIVE,unit=2),
            Pin(num='11',name='~',func=pin_types.OUTPUT,unit=2),
            Pin(num='12',name='V-',func=pin_types.PWRIN,unit=2),
            Pin(num='13',name='V-',func=pin_types.PWRIN,unit=2),
            Pin(num='14',name='-',func=pin_types.INPUT,unit=2),
            Pin(num='15',name='+',func=pin_types.INPUT,unit=2)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['1', '6', '7', '4', '3', '8', '5', '2', '9']},{'label': 'uB', 'num': 2, 'pin_nums': ['15', '10', '13', '11', '14', '12']}] }),
        Part(**{ 'name':'Si8241CB', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Si8241CB'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-16_3.9x9.9mm_P1.27mm', 'Package_SO:SOIC-16_3.9x9.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-16_3.9x9.9mm_P1.27mm', 'keywords':'class d gate driver', 'description':'', 'datasheet':'https://www.onsemi.com/pub/Collateral/NCD5702-D.PDF', 'search_text':'/usr/share/kicad/symbols/Amplifier_Audio.kicad_sym\nSi8241CB\n\nclass d gate driver', 'pins':[
            Pin(num='1',name='PWM',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='VOB',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='VDDB',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='13',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='14',name='GNDA',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VOA',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='3',name='VDDI',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='GNDI',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='DISABLE',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='DT',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='VDDI',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='GNDB',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Si8244BB', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Si8244BB'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-16_3.9x9.9mm_P1.27mm', 'Package_SO:SOIC-16_3.9x9.9mm_P1.27mm', 'Package_SO:SOIC-16_3.9x9.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-16_3.9x9.9mm_P1.27mm', 'keywords':'class d gate driver', 'description':'', 'datasheet':'https://www.onsemi.com/pub/Collateral/NCD5702-D.PDF', 'search_text':'/usr/share/kicad/symbols/Amplifier_Audio.kicad_sym\nSi8244BB\n\nclass d gate driver', 'pins':[
            Pin(num='1',name='PWM',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='VOB',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='VDDB',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='13',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='14',name='GNDA',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VOA',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='3',name='VDDI',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='GNDI',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='DISABLE',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='DT',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='VDDI',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='GNDB',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Si8244CB', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Si8244CB'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-16_3.9x9.9mm_P1.27mm', 'Package_SO:SOIC-16_3.9x9.9mm_P1.27mm', 'Package_SO:SOIC-16_3.9x9.9mm_P1.27mm', 'Package_SO:SOIC-16_3.9x9.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-16_3.9x9.9mm_P1.27mm', 'keywords':'class d gate driver', 'description':'', 'datasheet':'https://www.onsemi.com/pub/Collateral/NCD5702-D.PDF', 'search_text':'/usr/share/kicad/symbols/Amplifier_Audio.kicad_sym\nSi8244CB\n\nclass d gate driver', 'pins':[
            Pin(num='1',name='PWM',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='VOB',func=pin_types.OUTPUT,unit=1),
            Pin(num='11',name='VDDB',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='13',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='14',name='GNDA',func=pin_types.PWRIN,unit=1),
            Pin(num='15',name='VOA',func=pin_types.OUTPUT,unit=1),
            Pin(num='16',name='VDDA',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='3',name='VDDI',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='GNDI',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='DISABLE',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='DT',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='VDDI',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='GNDB',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TDA2050', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TDA2050'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_THT:TO-220-5_P3.4x3.7mm_StaggerOdd_Lead3.8mm_Vertical', 'Package_TO_SOT_THT:TO-220-5_P3.4x3.7mm_StaggerOdd_Lead3.8mm_Vertical'], 'footprint':'Package_TO_SOT_THT:TO-220-5_P3.4x3.7mm_StaggerOdd_Lead3.8mm_Vertical', 'keywords':'audio amplifier', 'description':'', 'datasheet':'http://www.st.com/resource/en/datasheet/cd00000131.pdf', 'search_text':'/usr/share/kicad/symbols/Amplifier_Audio.kicad_sym\nTDA2050\n\naudio amplifier', 'pins':[
            Pin(num='1',name='+',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='-',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='-Vs',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='+Vs',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TDA7265B', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TDA7265B'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_THT:TO-220-11_P3.4x5.08mm_StaggerOdd_Lead4.85mm_Vertical', 'Package_TO_SOT_THT:TO-220-11_P3.4x5.08mm_StaggerOdd_Lead4.85mm_Vertical'], 'footprint':'Package_TO_SOT_THT:TO-220-11_P3.4x5.08mm_StaggerOdd_Lead4.85mm_Vertical', 'keywords':'audio amplifier 2ch', 'description':'', 'datasheet':'http://www.st.com/resource/en/datasheet/tda7265b.pdf', 'search_text':'/usr/share/kicad/symbols/Amplifier_Audio.kicad_sym\nTDA7265B\n\naudio amplifier 2ch', 'pins':[
            Pin(num='10',name='-',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='+',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='MUTE',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='~',func=pin_types.OUTPUT,unit=2),
            Pin(num='7',name='+',func=pin_types.INPUT,unit=2),
            Pin(num='8',name='-',func=pin_types.INPUT,unit=2),
            Pin(num='1',name='V-',func=pin_types.PWRIN,unit=3),
            Pin(num='3',name='V+',func=pin_types.PWRIN,unit=3),
            Pin(num='6',name='V-',func=pin_types.PASSIVE,unit=3)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['9', '10', '2', '5', '11']},{'label': 'uB', 'num': 2, 'pin_nums': ['7', '8', '4']},{'label': 'uC', 'num': 3, 'pin_nums': ['3', '6', '1']}] }),
        Part(**{ 'name':'TDA7269A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TDA7269A'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_THT:TO-220-11_P3.4x5.08mm_StaggerOdd_Lead4.85mm_Vertical', 'Package_TO_SOT_THT:TO-220-11_P3.4x5.08mm_StaggerOdd_Lead4.85mm_Vertical', 'Package_TO_SOT_THT:TO-220-11_P3.4x5.08mm_StaggerOdd_Lead4.85mm_Vertical'], 'footprint':'Package_TO_SOT_THT:TO-220-11_P3.4x5.08mm_StaggerOdd_Lead4.85mm_Vertical', 'keywords':'audio amplfier 2ch', 'description':'', 'datasheet':'http://www.st.com/resource/en/datasheet/tda7269a.pdf', 'search_text':'/usr/share/kicad/symbols/Amplifier_Audio.kicad_sym\nTDA7269A\n\naudio amplfier 2ch', 'pins':[
            Pin(num='10',name='-',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='+',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='MUTE',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='~',func=pin_types.OUTPUT,unit=2),
            Pin(num='7',name='+',func=pin_types.INPUT,unit=2),
            Pin(num='8',name='-',func=pin_types.INPUT,unit=2),
            Pin(num='1',name='V-',func=pin_types.PWRIN,unit=3),
            Pin(num='3',name='V+',func=pin_types.PWRIN,unit=3),
            Pin(num='6',name='V-',func=pin_types.PASSIVE,unit=3)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['2', '10', '5', '11', '9']},{'label': 'uB', 'num': 2, 'pin_nums': ['7', '8', '4']},{'label': 'uC', 'num': 3, 'pin_nums': ['1', '3', '6']}] }),
        Part(**{ 'name':'TDA7292', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TDA7292'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_THT:TO-220-11_P3.4x5.08mm_StaggerOdd_Lead4.85mm_Vertical', 'Package_TO_SOT_THT:TO-220-11_P3.4x5.08mm_StaggerOdd_Lead4.85mm_Vertical', 'Package_TO_SOT_THT:TO-220-11_P3.4x5.08mm_StaggerOdd_Lead4.85mm_Vertical', 'Package_TO_SOT_THT:TO-220-11_P3.4x5.08mm_StaggerOdd_Lead4.85mm_Vertical'], 'footprint':'Package_TO_SOT_THT:TO-220-11_P3.4x5.08mm_StaggerOdd_Lead4.85mm_Vertical', 'keywords':'audio amplifier 2ch', 'description':'', 'datasheet':'http://www.st.com/resource/en/datasheet/tda7292.pdf', 'search_text':'/usr/share/kicad/symbols/Amplifier_Audio.kicad_sym\nTDA7292\n\naudio amplifier 2ch', 'pins':[
            Pin(num='10',name='-',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='+',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='MUTE',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='~',func=pin_types.OUTPUT,unit=2),
            Pin(num='7',name='+',func=pin_types.INPUT,unit=2),
            Pin(num='8',name='-',func=pin_types.INPUT,unit=2),
            Pin(num='1',name='V-',func=pin_types.PWRIN,unit=3),
            Pin(num='3',name='V+',func=pin_types.PWRIN,unit=3),
            Pin(num='6',name='V-',func=pin_types.PASSIVE,unit=3)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['2', '10', '5', '9', '11']},{'label': 'uB', 'num': 2, 'pin_nums': ['7', '8', '4']},{'label': 'uC', 'num': 3, 'pin_nums': ['3', '6', '1']}] }),
        Part(**{ 'name':'TDA7294', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TDA7294'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_THT:TO-220-15_P2.54x2.54mm_StaggerOdd_Lead4.58mm_Vertical', 'Package_TO_SOT_THT:TO-220-15_P2.54x2.54mm_StaggerOdd_Lead4.58mm_Vertical'], 'footprint':'Package_TO_SOT_THT:TO-220-15_P2.54x2.54mm_StaggerOdd_Lead4.58mm_Vertical', 'keywords':'audio amplifier', 'description':'', 'datasheet':'http://www.st.com/resource/en/datasheet/tda7294.pdf', 'search_text':'/usr/share/kicad/symbols/Amplifier_Audio.kicad_sym\nTDA7294\n\naudio amplifier', 'pins':[
            Pin(num='1',name='SGND',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='MUTE',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='12',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='13',name='+Vs',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='-Vs',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='-',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='+',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='SIG_GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='BOOT',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='+Vs',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='-Vs',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='STBY',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TDA7295', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TDA7295'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_THT:TO-220-15_P2.54x2.54mm_StaggerOdd_Lead4.58mm_Vertical', 'Package_TO_SOT_THT:TO-220-15_P2.54x2.54mm_StaggerOdd_Lead4.58mm_Vertical', 'Package_TO_SOT_THT:TO-220-15_P2.54x2.54mm_StaggerOdd_Lead4.58mm_Vertical'], 'footprint':'Package_TO_SOT_THT:TO-220-15_P2.54x2.54mm_StaggerOdd_Lead4.58mm_Vertical', 'keywords':'audio amplifier', 'description':'', 'datasheet':'http://www.st.com/resource/en/datasheet/tda7295.pdf', 'search_text':'/usr/share/kicad/symbols/Amplifier_Audio.kicad_sym\nTDA7295\n\naudio amplifier', 'pins':[
            Pin(num='1',name='SGND',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='MUTE',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='12',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='13',name='+Vs',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='-Vs',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='-',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='+',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='SIG_GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='BOOT',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='+Vs',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='-Vs',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='STBY',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TDA7296', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TDA7296'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_THT:TO-220-15_P2.54x2.54mm_StaggerOdd_Lead4.58mm_Vertical', 'Package_TO_SOT_THT:TO-220-15_P2.54x2.54mm_StaggerOdd_Lead4.58mm_Vertical', 'Package_TO_SOT_THT:TO-220-15_P2.54x2.54mm_StaggerOdd_Lead4.58mm_Vertical', 'Package_TO_SOT_THT:TO-220-15_P2.54x2.54mm_StaggerOdd_Lead4.58mm_Vertical'], 'footprint':'Package_TO_SOT_THT:TO-220-15_P2.54x2.54mm_StaggerOdd_Lead4.58mm_Vertical', 'keywords':'audio amplifier', 'description':'', 'datasheet':'http://www.st.com/resource/en/datasheet/tda7296.pdf', 'search_text':'/usr/share/kicad/symbols/Amplifier_Audio.kicad_sym\nTDA7296\n\naudio amplifier', 'pins':[
            Pin(num='1',name='SGND',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='MUTE',func=pin_types.INPUT,unit=1),
            Pin(num='11',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='12',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='13',name='+Vs',func=pin_types.PWRIN,unit=1),
            Pin(num='14',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='15',name='-Vs',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='-',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='+',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='SIG_GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='BOOT',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='+Vs',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='-Vs',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='STBY',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'TDA7297', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TDA7297'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_THT:TO-220-15_P2.54x2.54mm_StaggerOdd_Lead4.58mm_Vertical', 'Package_TO_SOT_THT:TO-220-15_P2.54x2.54mm_StaggerOdd_Lead4.58mm_Vertical'], 'footprint':'Package_TO_SOT_THT:TO-220-15_P2.54x2.54mm_StaggerOdd_Lead4.58mm_Vertical', 'keywords':'audio amplifier 2ch', 'description':'', 'datasheet':'http://www.st.com/resource/en/datasheet/tda7297.pdf', 'search_text':'/usr/share/kicad/symbols/Amplifier_Audio.kicad_sym\nTDA7297\n\naudio amplifier 2ch', 'pins':[
            Pin(num='1',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='10',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='11',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='+',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='MUTE',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='STBY',func=pin_types.INPUT,unit=1),
            Pin(num='12',name='+',func=pin_types.INPUT,unit=2),
            Pin(num='14',name='~',func=pin_types.OUTPUT,unit=2),
            Pin(num='15',name='~',func=pin_types.OUTPUT,unit=2),
            Pin(num='13',name='V+',func=pin_types.PASSIVE,unit=3),
            Pin(num='3',name='V+',func=pin_types.PWRIN,unit=3),
            Pin(num='8',name='PG',func=pin_types.PWRIN,unit=3),
            Pin(num='9',name='SG',func=pin_types.PWRIN,unit=3)], 'unit_defs':[{'label': 'uA', 'num': 1, 'pin_nums': ['6', '4', '2', '10', '1', '5', '7', '11']},{'label': 'uB', 'num': 2, 'pin_nums': ['12', '15', '14']},{'label': 'uC', 'num': 3, 'pin_nums': ['9', '3', '8', '13']}] }),
        Part(**{ 'name':'TPA6203A1DRB', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'TPA6203A1DRB'}), 'ref_prefix':'U', 'fplist':['Package_SO:MSOP-8-1EP_3x3mm_P0.65mm_EP1.95x2.15mm_ThermalVias', 'Package_DFN_QFN:Texas_DRB0008A'], 'footprint':'Package_SO:MSOP-8-1EP_3x3mm_P0.65mm_EP1.95x2.15mm_ThermalVias', 'keywords':'Differential audio amplifier Mono', 'description':'', 'datasheet':'https://www.ti.com/lit/ds/symlink/tpa6203a1.pdf', 'search_text':'/usr/share/kicad/symbols/Amplifier_Audio.kicad_sym\nTPA6203A1DRB\n\nDifferential audio amplifier Mono', 'pins':[
            Pin(num='1',name='~{SHUTDOWN}',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='BYPASS',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='IN+',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='IN-',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='V_{O+}',func=pin_types.OUTPUT,unit=1),
            Pin(num='6',name='V_{DD}',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='V_{O-}',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] })])